#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MapTypeParam import MapTypeParam
from alipay.aop.api.domain.MapTypeParam import MapTypeParam
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class ApSummaryBillResponseDTO(object):

    def __init__(self):
        self._adjust_amount = None
        self._arrangement_no = None
        self._auto_confirm_date = None
        self._bill_amount = None
        self._bill_end_date = None
        self._bill_month = None
        self._bill_no = None
        self._bill_start_date = None
        self._bill_status = None
        self._bill_status_name = None
        self._biz_module = None
        self._biz_pd_code = None
        self._ccy = None
        self._ccy_code = None
        self._charge_item_code = None
        self._charge_off_period = None
        self._charge_off_period_type = None
        self._charge_off_period_type_name = None
        self._check_date = None
        self._clcn_basic_amount = None
        self._clcn_basic_type = None
        self._clcn_basic_type_name = None
        self._confirmed_amount = None
        self._exclude_tax_amount = None
        self._fund_settle_time = None
        self._inner_trade_flag = None
        self._inst_id = None
        self._invoice_status_desc = None
        self._invoiced_amount = None
        self._invoiced_amt = None
        self._payee_account_ext_info = None
        self._payee_account_no = None
        self._payee_account_type = None
        self._payee_account_type_name = None
        self._payee_ip_role_id = None
        self._payee_ip_role_id_source = None
        self._payer_account_ext_info = None
        self._payer_account_no = None
        self._payer_account_type = None
        self._payer_account_type_name = None
        self._payer_ip_role_id = None
        self._payer_ip_role_id_source = None
        self._real_bill_amount = None
        self._reconciliation_status = None
        self._reconciliation_status_name = None
        self._sales_product_code = None
        self._sales_product_name = None
        self._settle_biz_type = None
        self._settle_biz_type_name = None
        self._settle_ip_role_id = None
        self._settle_ip_role_id_source = None
        self._settle_ip_role_name = None
        self._settle_merchant_id = None
        self._settle_merchant_id_source = None
        self._settle_merchant_name = None
        self._settle_status = None
        self._settle_status_name = None
        self._settle_time_type = None
        self._settle_time_type_name = None
        self._settled_amount = None
        self._sign_ip_role_id = None
        self._sign_ip_role_id_source = None
        self._sign_merchant_id = None
        self._sign_merchant_id_source = None
        self._summary_dmsn_1 = None
        self._summary_dmsn_2 = None
        self._summary_dmsn_3 = None
        self._summary_dmsn_4 = None
        self._summary_dmsn_5 = None
        self._summary_dmsn_6 = None
        self._summary_dmsn_7 = None
        self._summary_dmsn_value = None
        self._tax_amount = None
        self._tax_rate = None
        self._tax_type = None
        self._tnt_inst_id = None
        self._un_confirmed_amount = None
        self._un_invoice_amt = None
        self._un_settled_amount = None
        self._version_flag = None

    @property
    def adjust_amount(self):
        return self._adjust_amount

    @adjust_amount.setter
    def adjust_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._adjust_amount = value
        else:
            self._adjust_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def arrangement_no(self):
        return self._arrangement_no

    @arrangement_no.setter
    def arrangement_no(self, value):
        self._arrangement_no = value
    @property
    def auto_confirm_date(self):
        return self._auto_confirm_date

    @auto_confirm_date.setter
    def auto_confirm_date(self, value):
        self._auto_confirm_date = value
    @property
    def bill_amount(self):
        return self._bill_amount

    @bill_amount.setter
    def bill_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._bill_amount = value
        else:
            self._bill_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def bill_end_date(self):
        return self._bill_end_date

    @bill_end_date.setter
    def bill_end_date(self, value):
        self._bill_end_date = value
    @property
    def bill_month(self):
        return self._bill_month

    @bill_month.setter
    def bill_month(self, value):
        self._bill_month = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def bill_start_date(self):
        return self._bill_start_date

    @bill_start_date.setter
    def bill_start_date(self, value):
        self._bill_start_date = value
    @property
    def bill_status(self):
        return self._bill_status

    @bill_status.setter
    def bill_status(self, value):
        self._bill_status = value
    @property
    def bill_status_name(self):
        return self._bill_status_name

    @bill_status_name.setter
    def bill_status_name(self, value):
        self._bill_status_name = value
    @property
    def biz_module(self):
        return self._biz_module

    @biz_module.setter
    def biz_module(self, value):
        self._biz_module = value
    @property
    def biz_pd_code(self):
        return self._biz_pd_code

    @biz_pd_code.setter
    def biz_pd_code(self, value):
        self._biz_pd_code = value
    @property
    def ccy(self):
        return self._ccy

    @ccy.setter
    def ccy(self, value):
        self._ccy = value
    @property
    def ccy_code(self):
        return self._ccy_code

    @ccy_code.setter
    def ccy_code(self, value):
        self._ccy_code = value
    @property
    def charge_item_code(self):
        return self._charge_item_code

    @charge_item_code.setter
    def charge_item_code(self, value):
        self._charge_item_code = value
    @property
    def charge_off_period(self):
        return self._charge_off_period

    @charge_off_period.setter
    def charge_off_period(self, value):
        self._charge_off_period = value
    @property
    def charge_off_period_type(self):
        return self._charge_off_period_type

    @charge_off_period_type.setter
    def charge_off_period_type(self, value):
        self._charge_off_period_type = value
    @property
    def charge_off_period_type_name(self):
        return self._charge_off_period_type_name

    @charge_off_period_type_name.setter
    def charge_off_period_type_name(self, value):
        self._charge_off_period_type_name = value
    @property
    def check_date(self):
        return self._check_date

    @check_date.setter
    def check_date(self, value):
        self._check_date = value
    @property
    def clcn_basic_amount(self):
        return self._clcn_basic_amount

    @clcn_basic_amount.setter
    def clcn_basic_amount(self, value):
        self._clcn_basic_amount = value
    @property
    def clcn_basic_type(self):
        return self._clcn_basic_type

    @clcn_basic_type.setter
    def clcn_basic_type(self, value):
        self._clcn_basic_type = value
    @property
    def clcn_basic_type_name(self):
        return self._clcn_basic_type_name

    @clcn_basic_type_name.setter
    def clcn_basic_type_name(self, value):
        self._clcn_basic_type_name = value
    @property
    def confirmed_amount(self):
        return self._confirmed_amount

    @confirmed_amount.setter
    def confirmed_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._confirmed_amount = value
        else:
            self._confirmed_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def exclude_tax_amount(self):
        return self._exclude_tax_amount

    @exclude_tax_amount.setter
    def exclude_tax_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._exclude_tax_amount = value
        else:
            self._exclude_tax_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def fund_settle_time(self):
        return self._fund_settle_time

    @fund_settle_time.setter
    def fund_settle_time(self, value):
        self._fund_settle_time = value
    @property
    def inner_trade_flag(self):
        return self._inner_trade_flag

    @inner_trade_flag.setter
    def inner_trade_flag(self, value):
        self._inner_trade_flag = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_status_desc(self):
        return self._invoice_status_desc

    @invoice_status_desc.setter
    def invoice_status_desc(self, value):
        self._invoice_status_desc = value
    @property
    def invoiced_amount(self):
        return self._invoiced_amount

    @invoiced_amount.setter
    def invoiced_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoiced_amount = value
        else:
            self._invoiced_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoiced_amt(self):
        return self._invoiced_amt

    @invoiced_amt.setter
    def invoiced_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoiced_amt = value
        else:
            self._invoiced_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def payee_account_ext_info(self):
        return self._payee_account_ext_info

    @payee_account_ext_info.setter
    def payee_account_ext_info(self, value):
        if isinstance(value, MapTypeParam):
            self._payee_account_ext_info = value
        else:
            self._payee_account_ext_info = MapTypeParam.from_alipay_dict(value)
    @property
    def payee_account_no(self):
        return self._payee_account_no

    @payee_account_no.setter
    def payee_account_no(self, value):
        self._payee_account_no = value
    @property
    def payee_account_type(self):
        return self._payee_account_type

    @payee_account_type.setter
    def payee_account_type(self, value):
        self._payee_account_type = value
    @property
    def payee_account_type_name(self):
        return self._payee_account_type_name

    @payee_account_type_name.setter
    def payee_account_type_name(self, value):
        self._payee_account_type_name = value
    @property
    def payee_ip_role_id(self):
        return self._payee_ip_role_id

    @payee_ip_role_id.setter
    def payee_ip_role_id(self, value):
        self._payee_ip_role_id = value
    @property
    def payee_ip_role_id_source(self):
        return self._payee_ip_role_id_source

    @payee_ip_role_id_source.setter
    def payee_ip_role_id_source(self, value):
        self._payee_ip_role_id_source = value
    @property
    def payer_account_ext_info(self):
        return self._payer_account_ext_info

    @payer_account_ext_info.setter
    def payer_account_ext_info(self, value):
        if isinstance(value, MapTypeParam):
            self._payer_account_ext_info = value
        else:
            self._payer_account_ext_info = MapTypeParam.from_alipay_dict(value)
    @property
    def payer_account_no(self):
        return self._payer_account_no

    @payer_account_no.setter
    def payer_account_no(self, value):
        self._payer_account_no = value
    @property
    def payer_account_type(self):
        return self._payer_account_type

    @payer_account_type.setter
    def payer_account_type(self, value):
        self._payer_account_type = value
    @property
    def payer_account_type_name(self):
        return self._payer_account_type_name

    @payer_account_type_name.setter
    def payer_account_type_name(self, value):
        self._payer_account_type_name = value
    @property
    def payer_ip_role_id(self):
        return self._payer_ip_role_id

    @payer_ip_role_id.setter
    def payer_ip_role_id(self, value):
        self._payer_ip_role_id = value
    @property
    def payer_ip_role_id_source(self):
        return self._payer_ip_role_id_source

    @payer_ip_role_id_source.setter
    def payer_ip_role_id_source(self, value):
        self._payer_ip_role_id_source = value
    @property
    def real_bill_amount(self):
        return self._real_bill_amount

    @real_bill_amount.setter
    def real_bill_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._real_bill_amount = value
        else:
            self._real_bill_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def reconciliation_status(self):
        return self._reconciliation_status

    @reconciliation_status.setter
    def reconciliation_status(self, value):
        self._reconciliation_status = value
    @property
    def reconciliation_status_name(self):
        return self._reconciliation_status_name

    @reconciliation_status_name.setter
    def reconciliation_status_name(self, value):
        self._reconciliation_status_name = value
    @property
    def sales_product_code(self):
        return self._sales_product_code

    @sales_product_code.setter
    def sales_product_code(self, value):
        self._sales_product_code = value
    @property
    def sales_product_name(self):
        return self._sales_product_name

    @sales_product_name.setter
    def sales_product_name(self, value):
        self._sales_product_name = value
    @property
    def settle_biz_type(self):
        return self._settle_biz_type

    @settle_biz_type.setter
    def settle_biz_type(self, value):
        self._settle_biz_type = value
    @property
    def settle_biz_type_name(self):
        return self._settle_biz_type_name

    @settle_biz_type_name.setter
    def settle_biz_type_name(self, value):
        self._settle_biz_type_name = value
    @property
    def settle_ip_role_id(self):
        return self._settle_ip_role_id

    @settle_ip_role_id.setter
    def settle_ip_role_id(self, value):
        self._settle_ip_role_id = value
    @property
    def settle_ip_role_id_source(self):
        return self._settle_ip_role_id_source

    @settle_ip_role_id_source.setter
    def settle_ip_role_id_source(self, value):
        self._settle_ip_role_id_source = value
    @property
    def settle_ip_role_name(self):
        return self._settle_ip_role_name

    @settle_ip_role_name.setter
    def settle_ip_role_name(self, value):
        self._settle_ip_role_name = value
    @property
    def settle_merchant_id(self):
        return self._settle_merchant_id

    @settle_merchant_id.setter
    def settle_merchant_id(self, value):
        self._settle_merchant_id = value
    @property
    def settle_merchant_id_source(self):
        return self._settle_merchant_id_source

    @settle_merchant_id_source.setter
    def settle_merchant_id_source(self, value):
        self._settle_merchant_id_source = value
    @property
    def settle_merchant_name(self):
        return self._settle_merchant_name

    @settle_merchant_name.setter
    def settle_merchant_name(self, value):
        self._settle_merchant_name = value
    @property
    def settle_status(self):
        return self._settle_status

    @settle_status.setter
    def settle_status(self, value):
        self._settle_status = value
    @property
    def settle_status_name(self):
        return self._settle_status_name

    @settle_status_name.setter
    def settle_status_name(self, value):
        self._settle_status_name = value
    @property
    def settle_time_type(self):
        return self._settle_time_type

    @settle_time_type.setter
    def settle_time_type(self, value):
        self._settle_time_type = value
    @property
    def settle_time_type_name(self):
        return self._settle_time_type_name

    @settle_time_type_name.setter
    def settle_time_type_name(self, value):
        self._settle_time_type_name = value
    @property
    def settled_amount(self):
        return self._settled_amount

    @settled_amount.setter
    def settled_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._settled_amount = value
        else:
            self._settled_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def sign_ip_role_id(self):
        return self._sign_ip_role_id

    @sign_ip_role_id.setter
    def sign_ip_role_id(self, value):
        self._sign_ip_role_id = value
    @property
    def sign_ip_role_id_source(self):
        return self._sign_ip_role_id_source

    @sign_ip_role_id_source.setter
    def sign_ip_role_id_source(self, value):
        self._sign_ip_role_id_source = value
    @property
    def sign_merchant_id(self):
        return self._sign_merchant_id

    @sign_merchant_id.setter
    def sign_merchant_id(self, value):
        self._sign_merchant_id = value
    @property
    def sign_merchant_id_source(self):
        return self._sign_merchant_id_source

    @sign_merchant_id_source.setter
    def sign_merchant_id_source(self, value):
        self._sign_merchant_id_source = value
    @property
    def summary_dmsn_1(self):
        return self._summary_dmsn_1

    @summary_dmsn_1.setter
    def summary_dmsn_1(self, value):
        self._summary_dmsn_1 = value
    @property
    def summary_dmsn_2(self):
        return self._summary_dmsn_2

    @summary_dmsn_2.setter
    def summary_dmsn_2(self, value):
        self._summary_dmsn_2 = value
    @property
    def summary_dmsn_3(self):
        return self._summary_dmsn_3

    @summary_dmsn_3.setter
    def summary_dmsn_3(self, value):
        self._summary_dmsn_3 = value
    @property
    def summary_dmsn_4(self):
        return self._summary_dmsn_4

    @summary_dmsn_4.setter
    def summary_dmsn_4(self, value):
        self._summary_dmsn_4 = value
    @property
    def summary_dmsn_5(self):
        return self._summary_dmsn_5

    @summary_dmsn_5.setter
    def summary_dmsn_5(self, value):
        self._summary_dmsn_5 = value
    @property
    def summary_dmsn_6(self):
        return self._summary_dmsn_6

    @summary_dmsn_6.setter
    def summary_dmsn_6(self, value):
        self._summary_dmsn_6 = value
    @property
    def summary_dmsn_7(self):
        return self._summary_dmsn_7

    @summary_dmsn_7.setter
    def summary_dmsn_7(self, value):
        self._summary_dmsn_7 = value
    @property
    def summary_dmsn_value(self):
        return self._summary_dmsn_value

    @summary_dmsn_value.setter
    def summary_dmsn_value(self, value):
        self._summary_dmsn_value = value
    @property
    def tax_amount(self):
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._tax_amount = value
        else:
            self._tax_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def tax_rate(self):
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, value):
        self._tax_rate = value
    @property
    def tax_type(self):
        return self._tax_type

    @tax_type.setter
    def tax_type(self, value):
        self._tax_type = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def un_confirmed_amount(self):
        return self._un_confirmed_amount

    @un_confirmed_amount.setter
    def un_confirmed_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._un_confirmed_amount = value
        else:
            self._un_confirmed_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def un_invoice_amt(self):
        return self._un_invoice_amt

    @un_invoice_amt.setter
    def un_invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._un_invoice_amt = value
        else:
            self._un_invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def un_settled_amount(self):
        return self._un_settled_amount

    @un_settled_amount.setter
    def un_settled_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._un_settled_amount = value
        else:
            self._un_settled_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def version_flag(self):
        return self._version_flag

    @version_flag.setter
    def version_flag(self, value):
        self._version_flag = value


    def to_alipay_dict(self):
        params = dict()
        if self.adjust_amount:
            if hasattr(self.adjust_amount, 'to_alipay_dict'):
                params['adjust_amount'] = self.adjust_amount.to_alipay_dict()
            else:
                params['adjust_amount'] = self.adjust_amount
        if self.arrangement_no:
            if hasattr(self.arrangement_no, 'to_alipay_dict'):
                params['arrangement_no'] = self.arrangement_no.to_alipay_dict()
            else:
                params['arrangement_no'] = self.arrangement_no
        if self.auto_confirm_date:
            if hasattr(self.auto_confirm_date, 'to_alipay_dict'):
                params['auto_confirm_date'] = self.auto_confirm_date.to_alipay_dict()
            else:
                params['auto_confirm_date'] = self.auto_confirm_date
        if self.bill_amount:
            if hasattr(self.bill_amount, 'to_alipay_dict'):
                params['bill_amount'] = self.bill_amount.to_alipay_dict()
            else:
                params['bill_amount'] = self.bill_amount
        if self.bill_end_date:
            if hasattr(self.bill_end_date, 'to_alipay_dict'):
                params['bill_end_date'] = self.bill_end_date.to_alipay_dict()
            else:
                params['bill_end_date'] = self.bill_end_date
        if self.bill_month:
            if hasattr(self.bill_month, 'to_alipay_dict'):
                params['bill_month'] = self.bill_month.to_alipay_dict()
            else:
                params['bill_month'] = self.bill_month
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.bill_start_date:
            if hasattr(self.bill_start_date, 'to_alipay_dict'):
                params['bill_start_date'] = self.bill_start_date.to_alipay_dict()
            else:
                params['bill_start_date'] = self.bill_start_date
        if self.bill_status:
            if hasattr(self.bill_status, 'to_alipay_dict'):
                params['bill_status'] = self.bill_status.to_alipay_dict()
            else:
                params['bill_status'] = self.bill_status
        if self.bill_status_name:
            if hasattr(self.bill_status_name, 'to_alipay_dict'):
                params['bill_status_name'] = self.bill_status_name.to_alipay_dict()
            else:
                params['bill_status_name'] = self.bill_status_name
        if self.biz_module:
            if hasattr(self.biz_module, 'to_alipay_dict'):
                params['biz_module'] = self.biz_module.to_alipay_dict()
            else:
                params['biz_module'] = self.biz_module
        if self.biz_pd_code:
            if hasattr(self.biz_pd_code, 'to_alipay_dict'):
                params['biz_pd_code'] = self.biz_pd_code.to_alipay_dict()
            else:
                params['biz_pd_code'] = self.biz_pd_code
        if self.ccy:
            if hasattr(self.ccy, 'to_alipay_dict'):
                params['ccy'] = self.ccy.to_alipay_dict()
            else:
                params['ccy'] = self.ccy
        if self.ccy_code:
            if hasattr(self.ccy_code, 'to_alipay_dict'):
                params['ccy_code'] = self.ccy_code.to_alipay_dict()
            else:
                params['ccy_code'] = self.ccy_code
        if self.charge_item_code:
            if hasattr(self.charge_item_code, 'to_alipay_dict'):
                params['charge_item_code'] = self.charge_item_code.to_alipay_dict()
            else:
                params['charge_item_code'] = self.charge_item_code
        if self.charge_off_period:
            if hasattr(self.charge_off_period, 'to_alipay_dict'):
                params['charge_off_period'] = self.charge_off_period.to_alipay_dict()
            else:
                params['charge_off_period'] = self.charge_off_period
        if self.charge_off_period_type:
            if hasattr(self.charge_off_period_type, 'to_alipay_dict'):
                params['charge_off_period_type'] = self.charge_off_period_type.to_alipay_dict()
            else:
                params['charge_off_period_type'] = self.charge_off_period_type
        if self.charge_off_period_type_name:
            if hasattr(self.charge_off_period_type_name, 'to_alipay_dict'):
                params['charge_off_period_type_name'] = self.charge_off_period_type_name.to_alipay_dict()
            else:
                params['charge_off_period_type_name'] = self.charge_off_period_type_name
        if self.check_date:
            if hasattr(self.check_date, 'to_alipay_dict'):
                params['check_date'] = self.check_date.to_alipay_dict()
            else:
                params['check_date'] = self.check_date
        if self.clcn_basic_amount:
            if hasattr(self.clcn_basic_amount, 'to_alipay_dict'):
                params['clcn_basic_amount'] = self.clcn_basic_amount.to_alipay_dict()
            else:
                params['clcn_basic_amount'] = self.clcn_basic_amount
        if self.clcn_basic_type:
            if hasattr(self.clcn_basic_type, 'to_alipay_dict'):
                params['clcn_basic_type'] = self.clcn_basic_type.to_alipay_dict()
            else:
                params['clcn_basic_type'] = self.clcn_basic_type
        if self.clcn_basic_type_name:
            if hasattr(self.clcn_basic_type_name, 'to_alipay_dict'):
                params['clcn_basic_type_name'] = self.clcn_basic_type_name.to_alipay_dict()
            else:
                params['clcn_basic_type_name'] = self.clcn_basic_type_name
        if self.confirmed_amount:
            if hasattr(self.confirmed_amount, 'to_alipay_dict'):
                params['confirmed_amount'] = self.confirmed_amount.to_alipay_dict()
            else:
                params['confirmed_amount'] = self.confirmed_amount
        if self.exclude_tax_amount:
            if hasattr(self.exclude_tax_amount, 'to_alipay_dict'):
                params['exclude_tax_amount'] = self.exclude_tax_amount.to_alipay_dict()
            else:
                params['exclude_tax_amount'] = self.exclude_tax_amount
        if self.fund_settle_time:
            if hasattr(self.fund_settle_time, 'to_alipay_dict'):
                params['fund_settle_time'] = self.fund_settle_time.to_alipay_dict()
            else:
                params['fund_settle_time'] = self.fund_settle_time
        if self.inner_trade_flag:
            if hasattr(self.inner_trade_flag, 'to_alipay_dict'):
                params['inner_trade_flag'] = self.inner_trade_flag.to_alipay_dict()
            else:
                params['inner_trade_flag'] = self.inner_trade_flag
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_status_desc:
            if hasattr(self.invoice_status_desc, 'to_alipay_dict'):
                params['invoice_status_desc'] = self.invoice_status_desc.to_alipay_dict()
            else:
                params['invoice_status_desc'] = self.invoice_status_desc
        if self.invoiced_amount:
            if hasattr(self.invoiced_amount, 'to_alipay_dict'):
                params['invoiced_amount'] = self.invoiced_amount.to_alipay_dict()
            else:
                params['invoiced_amount'] = self.invoiced_amount
        if self.invoiced_amt:
            if hasattr(self.invoiced_amt, 'to_alipay_dict'):
                params['invoiced_amt'] = self.invoiced_amt.to_alipay_dict()
            else:
                params['invoiced_amt'] = self.invoiced_amt
        if self.payee_account_ext_info:
            if hasattr(self.payee_account_ext_info, 'to_alipay_dict'):
                params['payee_account_ext_info'] = self.payee_account_ext_info.to_alipay_dict()
            else:
                params['payee_account_ext_info'] = self.payee_account_ext_info
        if self.payee_account_no:
            if hasattr(self.payee_account_no, 'to_alipay_dict'):
                params['payee_account_no'] = self.payee_account_no.to_alipay_dict()
            else:
                params['payee_account_no'] = self.payee_account_no
        if self.payee_account_type:
            if hasattr(self.payee_account_type, 'to_alipay_dict'):
                params['payee_account_type'] = self.payee_account_type.to_alipay_dict()
            else:
                params['payee_account_type'] = self.payee_account_type
        if self.payee_account_type_name:
            if hasattr(self.payee_account_type_name, 'to_alipay_dict'):
                params['payee_account_type_name'] = self.payee_account_type_name.to_alipay_dict()
            else:
                params['payee_account_type_name'] = self.payee_account_type_name
        if self.payee_ip_role_id:
            if hasattr(self.payee_ip_role_id, 'to_alipay_dict'):
                params['payee_ip_role_id'] = self.payee_ip_role_id.to_alipay_dict()
            else:
                params['payee_ip_role_id'] = self.payee_ip_role_id
        if self.payee_ip_role_id_source:
            if hasattr(self.payee_ip_role_id_source, 'to_alipay_dict'):
                params['payee_ip_role_id_source'] = self.payee_ip_role_id_source.to_alipay_dict()
            else:
                params['payee_ip_role_id_source'] = self.payee_ip_role_id_source
        if self.payer_account_ext_info:
            if hasattr(self.payer_account_ext_info, 'to_alipay_dict'):
                params['payer_account_ext_info'] = self.payer_account_ext_info.to_alipay_dict()
            else:
                params['payer_account_ext_info'] = self.payer_account_ext_info
        if self.payer_account_no:
            if hasattr(self.payer_account_no, 'to_alipay_dict'):
                params['payer_account_no'] = self.payer_account_no.to_alipay_dict()
            else:
                params['payer_account_no'] = self.payer_account_no
        if self.payer_account_type:
            if hasattr(self.payer_account_type, 'to_alipay_dict'):
                params['payer_account_type'] = self.payer_account_type.to_alipay_dict()
            else:
                params['payer_account_type'] = self.payer_account_type
        if self.payer_account_type_name:
            if hasattr(self.payer_account_type_name, 'to_alipay_dict'):
                params['payer_account_type_name'] = self.payer_account_type_name.to_alipay_dict()
            else:
                params['payer_account_type_name'] = self.payer_account_type_name
        if self.payer_ip_role_id:
            if hasattr(self.payer_ip_role_id, 'to_alipay_dict'):
                params['payer_ip_role_id'] = self.payer_ip_role_id.to_alipay_dict()
            else:
                params['payer_ip_role_id'] = self.payer_ip_role_id
        if self.payer_ip_role_id_source:
            if hasattr(self.payer_ip_role_id_source, 'to_alipay_dict'):
                params['payer_ip_role_id_source'] = self.payer_ip_role_id_source.to_alipay_dict()
            else:
                params['payer_ip_role_id_source'] = self.payer_ip_role_id_source
        if self.real_bill_amount:
            if hasattr(self.real_bill_amount, 'to_alipay_dict'):
                params['real_bill_amount'] = self.real_bill_amount.to_alipay_dict()
            else:
                params['real_bill_amount'] = self.real_bill_amount
        if self.reconciliation_status:
            if hasattr(self.reconciliation_status, 'to_alipay_dict'):
                params['reconciliation_status'] = self.reconciliation_status.to_alipay_dict()
            else:
                params['reconciliation_status'] = self.reconciliation_status
        if self.reconciliation_status_name:
            if hasattr(self.reconciliation_status_name, 'to_alipay_dict'):
                params['reconciliation_status_name'] = self.reconciliation_status_name.to_alipay_dict()
            else:
                params['reconciliation_status_name'] = self.reconciliation_status_name
        if self.sales_product_code:
            if hasattr(self.sales_product_code, 'to_alipay_dict'):
                params['sales_product_code'] = self.sales_product_code.to_alipay_dict()
            else:
                params['sales_product_code'] = self.sales_product_code
        if self.sales_product_name:
            if hasattr(self.sales_product_name, 'to_alipay_dict'):
                params['sales_product_name'] = self.sales_product_name.to_alipay_dict()
            else:
                params['sales_product_name'] = self.sales_product_name
        if self.settle_biz_type:
            if hasattr(self.settle_biz_type, 'to_alipay_dict'):
                params['settle_biz_type'] = self.settle_biz_type.to_alipay_dict()
            else:
                params['settle_biz_type'] = self.settle_biz_type
        if self.settle_biz_type_name:
            if hasattr(self.settle_biz_type_name, 'to_alipay_dict'):
                params['settle_biz_type_name'] = self.settle_biz_type_name.to_alipay_dict()
            else:
                params['settle_biz_type_name'] = self.settle_biz_type_name
        if self.settle_ip_role_id:
            if hasattr(self.settle_ip_role_id, 'to_alipay_dict'):
                params['settle_ip_role_id'] = self.settle_ip_role_id.to_alipay_dict()
            else:
                params['settle_ip_role_id'] = self.settle_ip_role_id
        if self.settle_ip_role_id_source:
            if hasattr(self.settle_ip_role_id_source, 'to_alipay_dict'):
                params['settle_ip_role_id_source'] = self.settle_ip_role_id_source.to_alipay_dict()
            else:
                params['settle_ip_role_id_source'] = self.settle_ip_role_id_source
        if self.settle_ip_role_name:
            if hasattr(self.settle_ip_role_name, 'to_alipay_dict'):
                params['settle_ip_role_name'] = self.settle_ip_role_name.to_alipay_dict()
            else:
                params['settle_ip_role_name'] = self.settle_ip_role_name
        if self.settle_merchant_id:
            if hasattr(self.settle_merchant_id, 'to_alipay_dict'):
                params['settle_merchant_id'] = self.settle_merchant_id.to_alipay_dict()
            else:
                params['settle_merchant_id'] = self.settle_merchant_id
        if self.settle_merchant_id_source:
            if hasattr(self.settle_merchant_id_source, 'to_alipay_dict'):
                params['settle_merchant_id_source'] = self.settle_merchant_id_source.to_alipay_dict()
            else:
                params['settle_merchant_id_source'] = self.settle_merchant_id_source
        if self.settle_merchant_name:
            if hasattr(self.settle_merchant_name, 'to_alipay_dict'):
                params['settle_merchant_name'] = self.settle_merchant_name.to_alipay_dict()
            else:
                params['settle_merchant_name'] = self.settle_merchant_name
        if self.settle_status:
            if hasattr(self.settle_status, 'to_alipay_dict'):
                params['settle_status'] = self.settle_status.to_alipay_dict()
            else:
                params['settle_status'] = self.settle_status
        if self.settle_status_name:
            if hasattr(self.settle_status_name, 'to_alipay_dict'):
                params['settle_status_name'] = self.settle_status_name.to_alipay_dict()
            else:
                params['settle_status_name'] = self.settle_status_name
        if self.settle_time_type:
            if hasattr(self.settle_time_type, 'to_alipay_dict'):
                params['settle_time_type'] = self.settle_time_type.to_alipay_dict()
            else:
                params['settle_time_type'] = self.settle_time_type
        if self.settle_time_type_name:
            if hasattr(self.settle_time_type_name, 'to_alipay_dict'):
                params['settle_time_type_name'] = self.settle_time_type_name.to_alipay_dict()
            else:
                params['settle_time_type_name'] = self.settle_time_type_name
        if self.settled_amount:
            if hasattr(self.settled_amount, 'to_alipay_dict'):
                params['settled_amount'] = self.settled_amount.to_alipay_dict()
            else:
                params['settled_amount'] = self.settled_amount
        if self.sign_ip_role_id:
            if hasattr(self.sign_ip_role_id, 'to_alipay_dict'):
                params['sign_ip_role_id'] = self.sign_ip_role_id.to_alipay_dict()
            else:
                params['sign_ip_role_id'] = self.sign_ip_role_id
        if self.sign_ip_role_id_source:
            if hasattr(self.sign_ip_role_id_source, 'to_alipay_dict'):
                params['sign_ip_role_id_source'] = self.sign_ip_role_id_source.to_alipay_dict()
            else:
                params['sign_ip_role_id_source'] = self.sign_ip_role_id_source
        if self.sign_merchant_id:
            if hasattr(self.sign_merchant_id, 'to_alipay_dict'):
                params['sign_merchant_id'] = self.sign_merchant_id.to_alipay_dict()
            else:
                params['sign_merchant_id'] = self.sign_merchant_id
        if self.sign_merchant_id_source:
            if hasattr(self.sign_merchant_id_source, 'to_alipay_dict'):
                params['sign_merchant_id_source'] = self.sign_merchant_id_source.to_alipay_dict()
            else:
                params['sign_merchant_id_source'] = self.sign_merchant_id_source
        if self.summary_dmsn_1:
            if hasattr(self.summary_dmsn_1, 'to_alipay_dict'):
                params['summary_dmsn_1'] = self.summary_dmsn_1.to_alipay_dict()
            else:
                params['summary_dmsn_1'] = self.summary_dmsn_1
        if self.summary_dmsn_2:
            if hasattr(self.summary_dmsn_2, 'to_alipay_dict'):
                params['summary_dmsn_2'] = self.summary_dmsn_2.to_alipay_dict()
            else:
                params['summary_dmsn_2'] = self.summary_dmsn_2
        if self.summary_dmsn_3:
            if hasattr(self.summary_dmsn_3, 'to_alipay_dict'):
                params['summary_dmsn_3'] = self.summary_dmsn_3.to_alipay_dict()
            else:
                params['summary_dmsn_3'] = self.summary_dmsn_3
        if self.summary_dmsn_4:
            if hasattr(self.summary_dmsn_4, 'to_alipay_dict'):
                params['summary_dmsn_4'] = self.summary_dmsn_4.to_alipay_dict()
            else:
                params['summary_dmsn_4'] = self.summary_dmsn_4
        if self.summary_dmsn_5:
            if hasattr(self.summary_dmsn_5, 'to_alipay_dict'):
                params['summary_dmsn_5'] = self.summary_dmsn_5.to_alipay_dict()
            else:
                params['summary_dmsn_5'] = self.summary_dmsn_5
        if self.summary_dmsn_6:
            if hasattr(self.summary_dmsn_6, 'to_alipay_dict'):
                params['summary_dmsn_6'] = self.summary_dmsn_6.to_alipay_dict()
            else:
                params['summary_dmsn_6'] = self.summary_dmsn_6
        if self.summary_dmsn_7:
            if hasattr(self.summary_dmsn_7, 'to_alipay_dict'):
                params['summary_dmsn_7'] = self.summary_dmsn_7.to_alipay_dict()
            else:
                params['summary_dmsn_7'] = self.summary_dmsn_7
        if self.summary_dmsn_value:
            if hasattr(self.summary_dmsn_value, 'to_alipay_dict'):
                params['summary_dmsn_value'] = self.summary_dmsn_value.to_alipay_dict()
            else:
                params['summary_dmsn_value'] = self.summary_dmsn_value
        if self.tax_amount:
            if hasattr(self.tax_amount, 'to_alipay_dict'):
                params['tax_amount'] = self.tax_amount.to_alipay_dict()
            else:
                params['tax_amount'] = self.tax_amount
        if self.tax_rate:
            if hasattr(self.tax_rate, 'to_alipay_dict'):
                params['tax_rate'] = self.tax_rate.to_alipay_dict()
            else:
                params['tax_rate'] = self.tax_rate
        if self.tax_type:
            if hasattr(self.tax_type, 'to_alipay_dict'):
                params['tax_type'] = self.tax_type.to_alipay_dict()
            else:
                params['tax_type'] = self.tax_type
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        if self.un_confirmed_amount:
            if hasattr(self.un_confirmed_amount, 'to_alipay_dict'):
                params['un_confirmed_amount'] = self.un_confirmed_amount.to_alipay_dict()
            else:
                params['un_confirmed_amount'] = self.un_confirmed_amount
        if self.un_invoice_amt:
            if hasattr(self.un_invoice_amt, 'to_alipay_dict'):
                params['un_invoice_amt'] = self.un_invoice_amt.to_alipay_dict()
            else:
                params['un_invoice_amt'] = self.un_invoice_amt
        if self.un_settled_amount:
            if hasattr(self.un_settled_amount, 'to_alipay_dict'):
                params['un_settled_amount'] = self.un_settled_amount.to_alipay_dict()
            else:
                params['un_settled_amount'] = self.un_settled_amount
        if self.version_flag:
            if hasattr(self.version_flag, 'to_alipay_dict'):
                params['version_flag'] = self.version_flag.to_alipay_dict()
            else:
                params['version_flag'] = self.version_flag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApSummaryBillResponseDTO()
        if 'adjust_amount' in d:
            o.adjust_amount = d['adjust_amount']
        if 'arrangement_no' in d:
            o.arrangement_no = d['arrangement_no']
        if 'auto_confirm_date' in d:
            o.auto_confirm_date = d['auto_confirm_date']
        if 'bill_amount' in d:
            o.bill_amount = d['bill_amount']
        if 'bill_end_date' in d:
            o.bill_end_date = d['bill_end_date']
        if 'bill_month' in d:
            o.bill_month = d['bill_month']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'bill_start_date' in d:
            o.bill_start_date = d['bill_start_date']
        if 'bill_status' in d:
            o.bill_status = d['bill_status']
        if 'bill_status_name' in d:
            o.bill_status_name = d['bill_status_name']
        if 'biz_module' in d:
            o.biz_module = d['biz_module']
        if 'biz_pd_code' in d:
            o.biz_pd_code = d['biz_pd_code']
        if 'ccy' in d:
            o.ccy = d['ccy']
        if 'ccy_code' in d:
            o.ccy_code = d['ccy_code']
        if 'charge_item_code' in d:
            o.charge_item_code = d['charge_item_code']
        if 'charge_off_period' in d:
            o.charge_off_period = d['charge_off_period']
        if 'charge_off_period_type' in d:
            o.charge_off_period_type = d['charge_off_period_type']
        if 'charge_off_period_type_name' in d:
            o.charge_off_period_type_name = d['charge_off_period_type_name']
        if 'check_date' in d:
            o.check_date = d['check_date']
        if 'clcn_basic_amount' in d:
            o.clcn_basic_amount = d['clcn_basic_amount']
        if 'clcn_basic_type' in d:
            o.clcn_basic_type = d['clcn_basic_type']
        if 'clcn_basic_type_name' in d:
            o.clcn_basic_type_name = d['clcn_basic_type_name']
        if 'confirmed_amount' in d:
            o.confirmed_amount = d['confirmed_amount']
        if 'exclude_tax_amount' in d:
            o.exclude_tax_amount = d['exclude_tax_amount']
        if 'fund_settle_time' in d:
            o.fund_settle_time = d['fund_settle_time']
        if 'inner_trade_flag' in d:
            o.inner_trade_flag = d['inner_trade_flag']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_status_desc' in d:
            o.invoice_status_desc = d['invoice_status_desc']
        if 'invoiced_amount' in d:
            o.invoiced_amount = d['invoiced_amount']
        if 'invoiced_amt' in d:
            o.invoiced_amt = d['invoiced_amt']
        if 'payee_account_ext_info' in d:
            o.payee_account_ext_info = d['payee_account_ext_info']
        if 'payee_account_no' in d:
            o.payee_account_no = d['payee_account_no']
        if 'payee_account_type' in d:
            o.payee_account_type = d['payee_account_type']
        if 'payee_account_type_name' in d:
            o.payee_account_type_name = d['payee_account_type_name']
        if 'payee_ip_role_id' in d:
            o.payee_ip_role_id = d['payee_ip_role_id']
        if 'payee_ip_role_id_source' in d:
            o.payee_ip_role_id_source = d['payee_ip_role_id_source']
        if 'payer_account_ext_info' in d:
            o.payer_account_ext_info = d['payer_account_ext_info']
        if 'payer_account_no' in d:
            o.payer_account_no = d['payer_account_no']
        if 'payer_account_type' in d:
            o.payer_account_type = d['payer_account_type']
        if 'payer_account_type_name' in d:
            o.payer_account_type_name = d['payer_account_type_name']
        if 'payer_ip_role_id' in d:
            o.payer_ip_role_id = d['payer_ip_role_id']
        if 'payer_ip_role_id_source' in d:
            o.payer_ip_role_id_source = d['payer_ip_role_id_source']
        if 'real_bill_amount' in d:
            o.real_bill_amount = d['real_bill_amount']
        if 'reconciliation_status' in d:
            o.reconciliation_status = d['reconciliation_status']
        if 'reconciliation_status_name' in d:
            o.reconciliation_status_name = d['reconciliation_status_name']
        if 'sales_product_code' in d:
            o.sales_product_code = d['sales_product_code']
        if 'sales_product_name' in d:
            o.sales_product_name = d['sales_product_name']
        if 'settle_biz_type' in d:
            o.settle_biz_type = d['settle_biz_type']
        if 'settle_biz_type_name' in d:
            o.settle_biz_type_name = d['settle_biz_type_name']
        if 'settle_ip_role_id' in d:
            o.settle_ip_role_id = d['settle_ip_role_id']
        if 'settle_ip_role_id_source' in d:
            o.settle_ip_role_id_source = d['settle_ip_role_id_source']
        if 'settle_ip_role_name' in d:
            o.settle_ip_role_name = d['settle_ip_role_name']
        if 'settle_merchant_id' in d:
            o.settle_merchant_id = d['settle_merchant_id']
        if 'settle_merchant_id_source' in d:
            o.settle_merchant_id_source = d['settle_merchant_id_source']
        if 'settle_merchant_name' in d:
            o.settle_merchant_name = d['settle_merchant_name']
        if 'settle_status' in d:
            o.settle_status = d['settle_status']
        if 'settle_status_name' in d:
            o.settle_status_name = d['settle_status_name']
        if 'settle_time_type' in d:
            o.settle_time_type = d['settle_time_type']
        if 'settle_time_type_name' in d:
            o.settle_time_type_name = d['settle_time_type_name']
        if 'settled_amount' in d:
            o.settled_amount = d['settled_amount']
        if 'sign_ip_role_id' in d:
            o.sign_ip_role_id = d['sign_ip_role_id']
        if 'sign_ip_role_id_source' in d:
            o.sign_ip_role_id_source = d['sign_ip_role_id_source']
        if 'sign_merchant_id' in d:
            o.sign_merchant_id = d['sign_merchant_id']
        if 'sign_merchant_id_source' in d:
            o.sign_merchant_id_source = d['sign_merchant_id_source']
        if 'summary_dmsn_1' in d:
            o.summary_dmsn_1 = d['summary_dmsn_1']
        if 'summary_dmsn_2' in d:
            o.summary_dmsn_2 = d['summary_dmsn_2']
        if 'summary_dmsn_3' in d:
            o.summary_dmsn_3 = d['summary_dmsn_3']
        if 'summary_dmsn_4' in d:
            o.summary_dmsn_4 = d['summary_dmsn_4']
        if 'summary_dmsn_5' in d:
            o.summary_dmsn_5 = d['summary_dmsn_5']
        if 'summary_dmsn_6' in d:
            o.summary_dmsn_6 = d['summary_dmsn_6']
        if 'summary_dmsn_7' in d:
            o.summary_dmsn_7 = d['summary_dmsn_7']
        if 'summary_dmsn_value' in d:
            o.summary_dmsn_value = d['summary_dmsn_value']
        if 'tax_amount' in d:
            o.tax_amount = d['tax_amount']
        if 'tax_rate' in d:
            o.tax_rate = d['tax_rate']
        if 'tax_type' in d:
            o.tax_type = d['tax_type']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        if 'un_confirmed_amount' in d:
            o.un_confirmed_amount = d['un_confirmed_amount']
        if 'un_invoice_amt' in d:
            o.un_invoice_amt = d['un_invoice_amt']
        if 'un_settled_amount' in d:
            o.un_settled_amount = d['un_settled_amount']
        if 'version_flag' in d:
            o.version_flag = d['version_flag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeskAreaEntity import DeskAreaEntity


class KoubeiCateringPosDeskareaSyncModel(object):

    def __init__(self):
        self._desk_area = None
        self._type = None

    @property
    def desk_area(self):
        return self._desk_area

    @desk_area.setter
    def desk_area(self, value):
        if isinstance(value, DeskAreaEntity):
            self._desk_area = value
        else:
            self._desk_area = DeskAreaEntity.from_alipay_dict(value)
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.desk_area:
            if hasattr(self.desk_area, 'to_alipay_dict'):
                params['desk_area'] = self.desk_area.to_alipay_dict()
            else:
                params['desk_area'] = self.desk_area
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosDeskareaSyncModel()
        if 'desk_area' in d:
            o.desk_area = d['desk_area']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantPayforprivilegeCardbinactivityCreateormodifyModel(object):

    def __init__(self):
        self._bank_code = None
        self._card_bin = None
        self._out_biz_no = None

    @property
    def bank_code(self):
        return self._bank_code

    @bank_code.setter
    def bank_code(self, value):
        self._bank_code = value
    @property
    def card_bin(self):
        return self._card_bin

    @card_bin.setter
    def card_bin(self, value):
        self._card_bin = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_code:
            if hasattr(self.bank_code, 'to_alipay_dict'):
                params['bank_code'] = self.bank_code.to_alipay_dict()
            else:
                params['bank_code'] = self.bank_code
        if self.card_bin:
            if hasattr(self.card_bin, 'to_alipay_dict'):
                params['card_bin'] = self.card_bin.to_alipay_dict()
            else:
                params['card_bin'] = self.card_bin
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantPayforprivilegeCardbinactivityCreateormodifyModel()
        if 'bank_code' in d:
            o.bank_code = d['bank_code']
        if 'card_bin' in d:
            o.card_bin = d['card_bin']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniHmcodeCreateModel(object):

    def __init__(self):
        self._describe = None
        self._hm_bg_color = None
        self._hm_front_color = None
        self._query_param = None
        self._url_param = None

    @property
    def describe(self):
        return self._describe

    @describe.setter
    def describe(self, value):
        self._describe = value
    @property
    def hm_bg_color(self):
        return self._hm_bg_color

    @hm_bg_color.setter
    def hm_bg_color(self, value):
        self._hm_bg_color = value
    @property
    def hm_front_color(self):
        return self._hm_front_color

    @hm_front_color.setter
    def hm_front_color(self, value):
        self._hm_front_color = value
    @property
    def query_param(self):
        return self._query_param

    @query_param.setter
    def query_param(self, value):
        self._query_param = value
    @property
    def url_param(self):
        return self._url_param

    @url_param.setter
    def url_param(self, value):
        self._url_param = value


    def to_alipay_dict(self):
        params = dict()
        if self.describe:
            if hasattr(self.describe, 'to_alipay_dict'):
                params['describe'] = self.describe.to_alipay_dict()
            else:
                params['describe'] = self.describe
        if self.hm_bg_color:
            if hasattr(self.hm_bg_color, 'to_alipay_dict'):
                params['hm_bg_color'] = self.hm_bg_color.to_alipay_dict()
            else:
                params['hm_bg_color'] = self.hm_bg_color
        if self.hm_front_color:
            if hasattr(self.hm_front_color, 'to_alipay_dict'):
                params['hm_front_color'] = self.hm_front_color.to_alipay_dict()
            else:
                params['hm_front_color'] = self.hm_front_color
        if self.query_param:
            if hasattr(self.query_param, 'to_alipay_dict'):
                params['query_param'] = self.query_param.to_alipay_dict()
            else:
                params['query_param'] = self.query_param
        if self.url_param:
            if hasattr(self.url_param, 'to_alipay_dict'):
                params['url_param'] = self.url_param.to_alipay_dict()
            else:
                params['url_param'] = self.url_param
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniHmcodeCreateModel()
        if 'describe' in d:
            o.describe = d['describe']
        if 'hm_bg_color' in d:
            o.hm_bg_color = d['hm_bg_color']
        if 'hm_front_color' in d:
            o.hm_front_color = d['hm_front_color']
        if 'query_param' in d:
            o.query_param = d['query_param']
        if 'url_param' in d:
            o.url_param = d['url_param']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandIsvDeviceBindModel(object):

    def __init__(self):
        self._biz_type = None
        self._device_sn = None
        self._item_id = None
        self._memo = None
        self._order_no = None
        self._shop_id = None
        self._supplier_no = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def supplier_no(self):
        return self._supplier_no

    @supplier_no.setter
    def supplier_no(self, value):
        self._supplier_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.supplier_no:
            if hasattr(self.supplier_no, 'to_alipay_dict'):
                params['supplier_no'] = self.supplier_no.to_alipay_dict()
            else:
                params['supplier_no'] = self.supplier_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIsvDeviceBindModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'supplier_no' in d:
            o.supplier_no = d['supplier_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OperateContext import OperateContext


class KoubeiRetailWmsWorkBatchqueryModel(object):

    def __init__(self):
        self._gmt_finished_from = None
        self._gmt_finished_to = None
        self._notice_out_biz_no = None
        self._notice_out_biz_type = None
        self._operate_context = None
        self._operator = None
        self._page_no = None
        self._page_size = None
        self._status = None
        self._warehouse_code = None
        self._work_type = None

    @property
    def gmt_finished_from(self):
        return self._gmt_finished_from

    @gmt_finished_from.setter
    def gmt_finished_from(self, value):
        self._gmt_finished_from = value
    @property
    def gmt_finished_to(self):
        return self._gmt_finished_to

    @gmt_finished_to.setter
    def gmt_finished_to(self, value):
        self._gmt_finished_to = value
    @property
    def notice_out_biz_no(self):
        return self._notice_out_biz_no

    @notice_out_biz_no.setter
    def notice_out_biz_no(self, value):
        self._notice_out_biz_no = value
    @property
    def notice_out_biz_type(self):
        return self._notice_out_biz_type

    @notice_out_biz_type.setter
    def notice_out_biz_type(self, value):
        self._notice_out_biz_type = value
    @property
    def operate_context(self):
        return self._operate_context

    @operate_context.setter
    def operate_context(self, value):
        if isinstance(value, OperateContext):
            self._operate_context = value
        else:
            self._operate_context = OperateContext.from_alipay_dict(value)
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value
    @property
    def work_type(self):
        return self._work_type

    @work_type.setter
    def work_type(self, value):
        self._work_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_finished_from:
            if hasattr(self.gmt_finished_from, 'to_alipay_dict'):
                params['gmt_finished_from'] = self.gmt_finished_from.to_alipay_dict()
            else:
                params['gmt_finished_from'] = self.gmt_finished_from
        if self.gmt_finished_to:
            if hasattr(self.gmt_finished_to, 'to_alipay_dict'):
                params['gmt_finished_to'] = self.gmt_finished_to.to_alipay_dict()
            else:
                params['gmt_finished_to'] = self.gmt_finished_to
        if self.notice_out_biz_no:
            if hasattr(self.notice_out_biz_no, 'to_alipay_dict'):
                params['notice_out_biz_no'] = self.notice_out_biz_no.to_alipay_dict()
            else:
                params['notice_out_biz_no'] = self.notice_out_biz_no
        if self.notice_out_biz_type:
            if hasattr(self.notice_out_biz_type, 'to_alipay_dict'):
                params['notice_out_biz_type'] = self.notice_out_biz_type.to_alipay_dict()
            else:
                params['notice_out_biz_type'] = self.notice_out_biz_type
        if self.operate_context:
            if hasattr(self.operate_context, 'to_alipay_dict'):
                params['operate_context'] = self.operate_context.to_alipay_dict()
            else:
                params['operate_context'] = self.operate_context
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        if self.work_type:
            if hasattr(self.work_type, 'to_alipay_dict'):
                params['work_type'] = self.work_type.to_alipay_dict()
            else:
                params['work_type'] = self.work_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiRetailWmsWorkBatchqueryModel()
        if 'gmt_finished_from' in d:
            o.gmt_finished_from = d['gmt_finished_from']
        if 'gmt_finished_to' in d:
            o.gmt_finished_to = d['gmt_finished_to']
        if 'notice_out_biz_no' in d:
            o.notice_out_biz_no = d['notice_out_biz_no']
        if 'notice_out_biz_type' in d:
            o.notice_out_biz_type = d['notice_out_biz_type']
        if 'operate_context' in d:
            o.operate_context = d['operate_context']
        if 'operator' in d:
            o.operator = d['operator']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'status' in d:
            o.status = d['status']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        if 'work_type' in d:
            o.work_type = d['work_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsAutoPointReceiveQueryModel(object):

    def __init__(self):
        self._auto_campaign_type = None
        self._open_id = None
        self._scene_type = None
        self._user_id = None

    @property
    def auto_campaign_type(self):
        return self._auto_campaign_type

    @auto_campaign_type.setter
    def auto_campaign_type(self, value):
        self._auto_campaign_type = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def scene_type(self):
        return self._scene_type

    @scene_type.setter
    def scene_type(self, value):
        self._scene_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.auto_campaign_type:
            if hasattr(self.auto_campaign_type, 'to_alipay_dict'):
                params['auto_campaign_type'] = self.auto_campaign_type.to_alipay_dict()
            else:
                params['auto_campaign_type'] = self.auto_campaign_type
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.scene_type:
            if hasattr(self.scene_type, 'to_alipay_dict'):
                params['scene_type'] = self.scene_type.to_alipay_dict()
            else:
                params['scene_type'] = self.scene_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsAutoPointReceiveQueryModel()
        if 'auto_campaign_type' in d:
            o.auto_campaign_type = d['auto_campaign_type']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'scene_type' in d:
            o.scene_type = d['scene_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GiftTemplateButtonBox(object):

    def __init__(self):
        self._button_url = None
        self._invalid_button_url = None

    @property
    def button_url(self):
        return self._button_url

    @button_url.setter
    def button_url(self, value):
        self._button_url = value
    @property
    def invalid_button_url(self):
        return self._invalid_button_url

    @invalid_button_url.setter
    def invalid_button_url(self, value):
        self._invalid_button_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.button_url:
            if hasattr(self.button_url, 'to_alipay_dict'):
                params['button_url'] = self.button_url.to_alipay_dict()
            else:
                params['button_url'] = self.button_url
        if self.invalid_button_url:
            if hasattr(self.invalid_button_url, 'to_alipay_dict'):
                params['invalid_button_url'] = self.invalid_button_url.to_alipay_dict()
            else:
                params['invalid_button_url'] = self.invalid_button_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GiftTemplateButtonBox()
        if 'button_url' in d:
            o.button_url = d['button_url']
        if 'invalid_button_url' in d:
            o.invalid_button_url = d['invalid_button_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessHoursDesc(object):

    def __init__(self):
        self._days_in_week = None
        self._hours = None

    @property
    def days_in_week(self):
        return self._days_in_week

    @days_in_week.setter
    def days_in_week(self, value):
        if isinstance(value, list):
            self._days_in_week = list()
            for i in value:
                self._days_in_week.append(i)
    @property
    def hours(self):
        return self._hours

    @hours.setter
    def hours(self, value):
        self._hours = value


    def to_alipay_dict(self):
        params = dict()
        if self.days_in_week:
            if isinstance(self.days_in_week, list):
                for i in range(0, len(self.days_in_week)):
                    element = self.days_in_week[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.days_in_week[i] = element.to_alipay_dict()
            if hasattr(self.days_in_week, 'to_alipay_dict'):
                params['days_in_week'] = self.days_in_week.to_alipay_dict()
            else:
                params['days_in_week'] = self.days_in_week
        if self.hours:
            if hasattr(self.hours, 'to_alipay_dict'):
                params['hours'] = self.hours.to_alipay_dict()
            else:
                params['hours'] = self.hours
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessHoursDesc()
        if 'days_in_week' in d:
            o.days_in_week = d['days_in_week']
        if 'hours' in d:
            o.hours = d['hours']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MiniVersionBaseInfo(object):

    def __init__(self):
        self._app_version = None
        self._build_source = None
        self._bundle_id = None
        self._dev_id = None
        self._gray_strategy = None
        self._mini_app_id = None
        self._status = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def build_source(self):
        return self._build_source

    @build_source.setter
    def build_source(self, value):
        self._build_source = value
    @property
    def bundle_id(self):
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, value):
        self._bundle_id = value
    @property
    def dev_id(self):
        return self._dev_id

    @dev_id.setter
    def dev_id(self, value):
        self._dev_id = value
    @property
    def gray_strategy(self):
        return self._gray_strategy

    @gray_strategy.setter
    def gray_strategy(self, value):
        self._gray_strategy = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.build_source:
            if hasattr(self.build_source, 'to_alipay_dict'):
                params['build_source'] = self.build_source.to_alipay_dict()
            else:
                params['build_source'] = self.build_source
        if self.bundle_id:
            if hasattr(self.bundle_id, 'to_alipay_dict'):
                params['bundle_id'] = self.bundle_id.to_alipay_dict()
            else:
                params['bundle_id'] = self.bundle_id
        if self.dev_id:
            if hasattr(self.dev_id, 'to_alipay_dict'):
                params['dev_id'] = self.dev_id.to_alipay_dict()
            else:
                params['dev_id'] = self.dev_id
        if self.gray_strategy:
            if hasattr(self.gray_strategy, 'to_alipay_dict'):
                params['gray_strategy'] = self.gray_strategy.to_alipay_dict()
            else:
                params['gray_strategy'] = self.gray_strategy
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MiniVersionBaseInfo()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'build_source' in d:
            o.build_source = d['build_source']
        if 'bundle_id' in d:
            o.bundle_id = d['bundle_id']
        if 'dev_id' in d:
            o.dev_id = d['dev_id']
        if 'gray_strategy' in d:
            o.gray_strategy = d['gray_strategy']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PayerAccountDTO(object):

    def __init__(self):
        self._asset_display_name = None
        self._asset_type = None

    @property
    def asset_display_name(self):
        return self._asset_display_name

    @asset_display_name.setter
    def asset_display_name(self, value):
        self._asset_display_name = value
    @property
    def asset_type(self):
        return self._asset_type

    @asset_type.setter
    def asset_type(self, value):
        self._asset_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_display_name:
            if hasattr(self.asset_display_name, 'to_alipay_dict'):
                params['asset_display_name'] = self.asset_display_name.to_alipay_dict()
            else:
                params['asset_display_name'] = self.asset_display_name
        if self.asset_type:
            if hasattr(self.asset_type, 'to_alipay_dict'):
                params['asset_type'] = self.asset_type.to_alipay_dict()
            else:
                params['asset_type'] = self.asset_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PayerAccountDTO()
        if 'asset_display_name' in d:
            o.asset_display_name = d['asset_display_name']
        if 'asset_type' in d:
            o.asset_type = d['asset_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataAiserviceCloudbusResourceUploadModel(object):

    def __init__(self):
        self._data = None
        self._res_name = None
        self._type = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def res_name(self):
        return self._res_name

    @res_name.setter
    def res_name(self, value):
        self._res_name = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.res_name:
            if hasattr(self.res_name, 'to_alipay_dict'):
                params['res_name'] = self.res_name.to_alipay_dict()
            else:
                params['res_name'] = self.res_name
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataAiserviceCloudbusResourceUploadModel()
        if 'data' in d:
            o.data = d['data']
        if 'res_name' in d:
            o.res_name = d['res_name']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiMarketingCampaignIntelligentTemplateConsultResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignIntelligentTemplateConsultResponse, self).__init__()
        self._template_codes = None

    @property
    def template_codes(self):
        return self._template_codes

    @template_codes.setter
    def template_codes(self, value):
        if isinstance(value, list):
            self._template_codes = list()
            for i in value:
                self._template_codes.append(i)

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignIntelligentTemplateConsultResponse, self).parse_response_content(response_content)
        if 'template_codes' in response:
            self.template_codes = response['template_codes']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShopDiscountInfo(object):

    def __init__(self):
        self._cover = None
        self._description = None
        self._is_all = None
        self._item_id = None
        self._promo_sub_type = None
        self._promotion_type = None
        self._purchase_mode = None
        self._sales_quantity = None
        self._subject = None

    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def is_all(self):
        return self._is_all

    @is_all.setter
    def is_all(self, value):
        self._is_all = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def promo_sub_type(self):
        return self._promo_sub_type

    @promo_sub_type.setter
    def promo_sub_type(self, value):
        self._promo_sub_type = value
    @property
    def promotion_type(self):
        return self._promotion_type

    @promotion_type.setter
    def promotion_type(self, value):
        self._promotion_type = value
    @property
    def purchase_mode(self):
        return self._purchase_mode

    @purchase_mode.setter
    def purchase_mode(self, value):
        self._purchase_mode = value
    @property
    def sales_quantity(self):
        return self._sales_quantity

    @sales_quantity.setter
    def sales_quantity(self, value):
        self._sales_quantity = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value


    def to_alipay_dict(self):
        params = dict()
        if self.cover:
            if hasattr(self.cover, 'to_alipay_dict'):
                params['cover'] = self.cover.to_alipay_dict()
            else:
                params['cover'] = self.cover
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.is_all:
            if hasattr(self.is_all, 'to_alipay_dict'):
                params['is_all'] = self.is_all.to_alipay_dict()
            else:
                params['is_all'] = self.is_all
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.promo_sub_type:
            if hasattr(self.promo_sub_type, 'to_alipay_dict'):
                params['promo_sub_type'] = self.promo_sub_type.to_alipay_dict()
            else:
                params['promo_sub_type'] = self.promo_sub_type
        if self.promotion_type:
            if hasattr(self.promotion_type, 'to_alipay_dict'):
                params['promotion_type'] = self.promotion_type.to_alipay_dict()
            else:
                params['promotion_type'] = self.promotion_type
        if self.purchase_mode:
            if hasattr(self.purchase_mode, 'to_alipay_dict'):
                params['purchase_mode'] = self.purchase_mode.to_alipay_dict()
            else:
                params['purchase_mode'] = self.purchase_mode
        if self.sales_quantity:
            if hasattr(self.sales_quantity, 'to_alipay_dict'):
                params['sales_quantity'] = self.sales_quantity.to_alipay_dict()
            else:
                params['sales_quantity'] = self.sales_quantity
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopDiscountInfo()
        if 'cover' in d:
            o.cover = d['cover']
        if 'description' in d:
            o.description = d['description']
        if 'is_all' in d:
            o.is_all = d['is_all']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'promo_sub_type' in d:
            o.promo_sub_type = d['promo_sub_type']
        if 'promotion_type' in d:
            o.promotion_type = d['promotion_type']
        if 'purchase_mode' in d:
            o.purchase_mode = d['purchase_mode']
        if 'sales_quantity' in d:
            o.sales_quantity = d['sales_quantity']
        if 'subject' in d:
            o.subject = d['subject']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncInputinvoiceInvoiceNotifyModel(object):

    def __init__(self):
        self._error_code = None
        self._error_msg = None
        self._id = None
        self._invoice_code = None
        self._invoice_no = None
        self._mq_key = None
        self._process_result = None
        self._process_type = None
        self._related_order = None
        self._task_id = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def mq_key(self):
        return self._mq_key

    @mq_key.setter
    def mq_key(self, value):
        self._mq_key = value
    @property
    def process_result(self):
        return self._process_result

    @process_result.setter
    def process_result(self, value):
        self._process_result = value
    @property
    def process_type(self):
        return self._process_type

    @process_type.setter
    def process_type(self, value):
        self._process_type = value
    @property
    def related_order(self):
        return self._related_order

    @related_order.setter
    def related_order(self, value):
        self._related_order = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.error_msg:
            if hasattr(self.error_msg, 'to_alipay_dict'):
                params['error_msg'] = self.error_msg.to_alipay_dict()
            else:
                params['error_msg'] = self.error_msg
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.mq_key:
            if hasattr(self.mq_key, 'to_alipay_dict'):
                params['mq_key'] = self.mq_key.to_alipay_dict()
            else:
                params['mq_key'] = self.mq_key
        if self.process_result:
            if hasattr(self.process_result, 'to_alipay_dict'):
                params['process_result'] = self.process_result.to_alipay_dict()
            else:
                params['process_result'] = self.process_result
        if self.process_type:
            if hasattr(self.process_type, 'to_alipay_dict'):
                params['process_type'] = self.process_type.to_alipay_dict()
            else:
                params['process_type'] = self.process_type
        if self.related_order:
            if hasattr(self.related_order, 'to_alipay_dict'):
                params['related_order'] = self.related_order.to_alipay_dict()
            else:
                params['related_order'] = self.related_order
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncInputinvoiceInvoiceNotifyModel()
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'error_msg' in d:
            o.error_msg = d['error_msg']
        if 'id' in d:
            o.id = d['id']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'mq_key' in d:
            o.mq_key = d['mq_key']
        if 'process_result' in d:
            o.process_result = d['process_result']
        if 'process_type' in d:
            o.process_type = d['process_type']
        if 'related_order' in d:
            o.related_order = d['related_order']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAuthAppAesGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAuthAppAesGetResponse, self).__init__()
        self._aes_key = None

    @property
    def aes_key(self):
        return self._aes_key

    @aes_key.setter
    def aes_key(self, value):
        self._aes_key = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAuthAppAesGetResponse, self).parse_response_content(response_content)
        if 'aes_key' in response:
            self.aes_key = response['aes_key']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCognitiveAswfDagQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCognitiveAswfDagQueryResponse, self).__init__()
        self._dag_id = None
        self._error_code = None
        self._error_msg = None
        self._success = None

    @property
    def dag_id(self):
        return self._dag_id

    @dag_id.setter
    def dag_id(self, value):
        self._dag_id = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCognitiveAswfDagQueryResponse, self).parse_response_content(response_content)
        if 'dag_id' in response:
            self.dag_id = response['dag_id']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_msg' in response:
            self.error_msg = response['error_msg']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RiskConsultResult(object):

    def __init__(self):
        self._consult_time = None
        self._risk_desc = None
        self._risk_level = None
        self._risk_scene = None

    @property
    def consult_time(self):
        return self._consult_time

    @consult_time.setter
    def consult_time(self, value):
        self._consult_time = value
    @property
    def risk_desc(self):
        return self._risk_desc

    @risk_desc.setter
    def risk_desc(self, value):
        self._risk_desc = value
    @property
    def risk_level(self):
        return self._risk_level

    @risk_level.setter
    def risk_level(self, value):
        self._risk_level = value
    @property
    def risk_scene(self):
        return self._risk_scene

    @risk_scene.setter
    def risk_scene(self, value):
        self._risk_scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.consult_time:
            if hasattr(self.consult_time, 'to_alipay_dict'):
                params['consult_time'] = self.consult_time.to_alipay_dict()
            else:
                params['consult_time'] = self.consult_time
        if self.risk_desc:
            if hasattr(self.risk_desc, 'to_alipay_dict'):
                params['risk_desc'] = self.risk_desc.to_alipay_dict()
            else:
                params['risk_desc'] = self.risk_desc
        if self.risk_level:
            if hasattr(self.risk_level, 'to_alipay_dict'):
                params['risk_level'] = self.risk_level.to_alipay_dict()
            else:
                params['risk_level'] = self.risk_level
        if self.risk_scene:
            if hasattr(self.risk_scene, 'to_alipay_dict'):
                params['risk_scene'] = self.risk_scene.to_alipay_dict()
            else:
                params['risk_scene'] = self.risk_scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RiskConsultResult()
        if 'consult_time' in d:
            o.consult_time = d['consult_time']
        if 'risk_desc' in d:
            o.risk_desc = d['risk_desc']
        if 'risk_level' in d:
            o.risk_level = d['risk_level']
        if 'risk_scene' in d:
            o.risk_scene = d['risk_scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VehActivityItem import VehActivityItem


class VehServiceItem(object):

    def __init__(self):
        self._activity_items = None
        self._desc = None
        self._key = None

    @property
    def activity_items(self):
        return self._activity_items

    @activity_items.setter
    def activity_items(self, value):
        if isinstance(value, VehActivityItem):
            self._activity_items = value
        else:
            self._activity_items = VehActivityItem.from_alipay_dict(value)
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_items:
            if hasattr(self.activity_items, 'to_alipay_dict'):
                params['activity_items'] = self.activity_items.to_alipay_dict()
            else:
                params['activity_items'] = self.activity_items
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VehServiceItem()
        if 'activity_items' in d:
            o.activity_items = d['activity_items']
        if 'desc' in d:
            o.desc = d['desc']
        if 'key' in d:
            o.key = d['key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPcreditCreditriskCustlabelQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPcreditCreditriskCustlabelQueryResponse, self).__init__()
        self._show_jb = None
        self._show_my = None

    @property
    def show_jb(self):
        return self._show_jb

    @show_jb.setter
    def show_jb(self, value):
        self._show_jb = value
    @property
    def show_my(self):
        return self._show_my

    @show_my.setter
    def show_my(self, value):
        self._show_my = value

    def parse_response_content(self, response_content):
        response = super(AlipayPcreditCreditriskCustlabelQueryResponse, self).parse_response_content(response_content)
        if 'show_jb' in response:
            self.show_jb = response['show_jb']
        if 'show_my' in response:
            self.show_my = response['show_my']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ActivityBaseInfo import ActivityBaseInfo
from alipay.aop.api.domain.VoucherAvailableScopeInfo import VoucherAvailableScopeInfo
from alipay.aop.api.domain.VoucherDeductInfo import VoucherDeductInfo
from alipay.aop.api.domain.VoucherDisplayPatternInfo import VoucherDisplayPatternInfo
from alipay.aop.api.domain.VoucherSendModeInfo import VoucherSendModeInfo
from alipay.aop.api.domain.VoucherUseRuleInfo import VoucherUseRuleInfo


class VoucherPackageActivityInfo(object):

    def __init__(self):
        self._activity_base_info = None
        self._voucher_available_scope_info = None
        self._voucher_deduct_info = None
        self._voucher_display_pattern_info = None
        self._voucher_send_mode_info = None
        self._voucher_use_rule_info = None

    @property
    def activity_base_info(self):
        return self._activity_base_info

    @activity_base_info.setter
    def activity_base_info(self, value):
        if isinstance(value, ActivityBaseInfo):
            self._activity_base_info = value
        else:
            self._activity_base_info = ActivityBaseInfo.from_alipay_dict(value)
    @property
    def voucher_available_scope_info(self):
        return self._voucher_available_scope_info

    @voucher_available_scope_info.setter
    def voucher_available_scope_info(self, value):
        if isinstance(value, VoucherAvailableScopeInfo):
            self._voucher_available_scope_info = value
        else:
            self._voucher_available_scope_info = VoucherAvailableScopeInfo.from_alipay_dict(value)
    @property
    def voucher_deduct_info(self):
        return self._voucher_deduct_info

    @voucher_deduct_info.setter
    def voucher_deduct_info(self, value):
        if isinstance(value, VoucherDeductInfo):
            self._voucher_deduct_info = value
        else:
            self._voucher_deduct_info = VoucherDeductInfo.from_alipay_dict(value)
    @property
    def voucher_display_pattern_info(self):
        return self._voucher_display_pattern_info

    @voucher_display_pattern_info.setter
    def voucher_display_pattern_info(self, value):
        if isinstance(value, VoucherDisplayPatternInfo):
            self._voucher_display_pattern_info = value
        else:
            self._voucher_display_pattern_info = VoucherDisplayPatternInfo.from_alipay_dict(value)
    @property
    def voucher_send_mode_info(self):
        return self._voucher_send_mode_info

    @voucher_send_mode_info.setter
    def voucher_send_mode_info(self, value):
        if isinstance(value, VoucherSendModeInfo):
            self._voucher_send_mode_info = value
        else:
            self._voucher_send_mode_info = VoucherSendModeInfo.from_alipay_dict(value)
    @property
    def voucher_use_rule_info(self):
        return self._voucher_use_rule_info

    @voucher_use_rule_info.setter
    def voucher_use_rule_info(self, value):
        if isinstance(value, VoucherUseRuleInfo):
            self._voucher_use_rule_info = value
        else:
            self._voucher_use_rule_info = VoucherUseRuleInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.activity_base_info:
            if hasattr(self.activity_base_info, 'to_alipay_dict'):
                params['activity_base_info'] = self.activity_base_info.to_alipay_dict()
            else:
                params['activity_base_info'] = self.activity_base_info
        if self.voucher_available_scope_info:
            if hasattr(self.voucher_available_scope_info, 'to_alipay_dict'):
                params['voucher_available_scope_info'] = self.voucher_available_scope_info.to_alipay_dict()
            else:
                params['voucher_available_scope_info'] = self.voucher_available_scope_info
        if self.voucher_deduct_info:
            if hasattr(self.voucher_deduct_info, 'to_alipay_dict'):
                params['voucher_deduct_info'] = self.voucher_deduct_info.to_alipay_dict()
            else:
                params['voucher_deduct_info'] = self.voucher_deduct_info
        if self.voucher_display_pattern_info:
            if hasattr(self.voucher_display_pattern_info, 'to_alipay_dict'):
                params['voucher_display_pattern_info'] = self.voucher_display_pattern_info.to_alipay_dict()
            else:
                params['voucher_display_pattern_info'] = self.voucher_display_pattern_info
        if self.voucher_send_mode_info:
            if hasattr(self.voucher_send_mode_info, 'to_alipay_dict'):
                params['voucher_send_mode_info'] = self.voucher_send_mode_info.to_alipay_dict()
            else:
                params['voucher_send_mode_info'] = self.voucher_send_mode_info
        if self.voucher_use_rule_info:
            if hasattr(self.voucher_use_rule_info, 'to_alipay_dict'):
                params['voucher_use_rule_info'] = self.voucher_use_rule_info.to_alipay_dict()
            else:
                params['voucher_use_rule_info'] = self.voucher_use_rule_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherPackageActivityInfo()
        if 'activity_base_info' in d:
            o.activity_base_info = d['activity_base_info']
        if 'voucher_available_scope_info' in d:
            o.voucher_available_scope_info = d['voucher_available_scope_info']
        if 'voucher_deduct_info' in d:
            o.voucher_deduct_info = d['voucher_deduct_info']
        if 'voucher_display_pattern_info' in d:
            o.voucher_display_pattern_info = d['voucher_display_pattern_info']
        if 'voucher_send_mode_info' in d:
            o.voucher_send_mode_info = d['voucher_send_mode_info']
        if 'voucher_use_rule_info' in d:
            o.voucher_use_rule_info = d['voucher_use_rule_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserDtbankQrcodeCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserDtbankQrcodeCreateResponse, self).__init__()
        self._qrcode = None
        self._qrcode_id = None
        self._qrcode_out_id = None

    @property
    def qrcode(self):
        return self._qrcode

    @qrcode.setter
    def qrcode(self, value):
        self._qrcode = value
    @property
    def qrcode_id(self):
        return self._qrcode_id

    @qrcode_id.setter
    def qrcode_id(self, value):
        self._qrcode_id = value
    @property
    def qrcode_out_id(self):
        return self._qrcode_out_id

    @qrcode_out_id.setter
    def qrcode_out_id(self, value):
        self._qrcode_out_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserDtbankQrcodeCreateResponse, self).parse_response_content(response_content)
        if 'qrcode' in response:
            self.qrcode = response['qrcode']
        if 'qrcode_id' in response:
            self.qrcode_id = response['qrcode_id']
        if 'qrcode_out_id' in response:
            self.qrcode_out_id = response['qrcode_out_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EduTradeExtInfo(object):

    def __init__(self):
        self._course_desc = None
        self._course_img_url = None
        self._course_name = None
        self._course_tag = None
        self._origin_price = None
        self._out_course_id = None
        self._out_shop_id = None
        self._price = None
        self._shop_img_url = None
        self._shop_name = None
        self._shop_url = None

    @property
    def course_desc(self):
        return self._course_desc

    @course_desc.setter
    def course_desc(self, value):
        self._course_desc = value
    @property
    def course_img_url(self):
        return self._course_img_url

    @course_img_url.setter
    def course_img_url(self, value):
        self._course_img_url = value
    @property
    def course_name(self):
        return self._course_name

    @course_name.setter
    def course_name(self, value):
        self._course_name = value
    @property
    def course_tag(self):
        return self._course_tag

    @course_tag.setter
    def course_tag(self, value):
        self._course_tag = value
    @property
    def origin_price(self):
        return self._origin_price

    @origin_price.setter
    def origin_price(self, value):
        self._origin_price = value
    @property
    def out_course_id(self):
        return self._out_course_id

    @out_course_id.setter
    def out_course_id(self, value):
        self._out_course_id = value
    @property
    def out_shop_id(self):
        return self._out_shop_id

    @out_shop_id.setter
    def out_shop_id(self, value):
        self._out_shop_id = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def shop_img_url(self):
        return self._shop_img_url

    @shop_img_url.setter
    def shop_img_url(self, value):
        self._shop_img_url = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_url(self):
        return self._shop_url

    @shop_url.setter
    def shop_url(self, value):
        self._shop_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.course_desc:
            if hasattr(self.course_desc, 'to_alipay_dict'):
                params['course_desc'] = self.course_desc.to_alipay_dict()
            else:
                params['course_desc'] = self.course_desc
        if self.course_img_url:
            if hasattr(self.course_img_url, 'to_alipay_dict'):
                params['course_img_url'] = self.course_img_url.to_alipay_dict()
            else:
                params['course_img_url'] = self.course_img_url
        if self.course_name:
            if hasattr(self.course_name, 'to_alipay_dict'):
                params['course_name'] = self.course_name.to_alipay_dict()
            else:
                params['course_name'] = self.course_name
        if self.course_tag:
            if hasattr(self.course_tag, 'to_alipay_dict'):
                params['course_tag'] = self.course_tag.to_alipay_dict()
            else:
                params['course_tag'] = self.course_tag
        if self.origin_price:
            if hasattr(self.origin_price, 'to_alipay_dict'):
                params['origin_price'] = self.origin_price.to_alipay_dict()
            else:
                params['origin_price'] = self.origin_price
        if self.out_course_id:
            if hasattr(self.out_course_id, 'to_alipay_dict'):
                params['out_course_id'] = self.out_course_id.to_alipay_dict()
            else:
                params['out_course_id'] = self.out_course_id
        if self.out_shop_id:
            if hasattr(self.out_shop_id, 'to_alipay_dict'):
                params['out_shop_id'] = self.out_shop_id.to_alipay_dict()
            else:
                params['out_shop_id'] = self.out_shop_id
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.shop_img_url:
            if hasattr(self.shop_img_url, 'to_alipay_dict'):
                params['shop_img_url'] = self.shop_img_url.to_alipay_dict()
            else:
                params['shop_img_url'] = self.shop_img_url
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_url:
            if hasattr(self.shop_url, 'to_alipay_dict'):
                params['shop_url'] = self.shop_url.to_alipay_dict()
            else:
                params['shop_url'] = self.shop_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EduTradeExtInfo()
        if 'course_desc' in d:
            o.course_desc = d['course_desc']
        if 'course_img_url' in d:
            o.course_img_url = d['course_img_url']
        if 'course_name' in d:
            o.course_name = d['course_name']
        if 'course_tag' in d:
            o.course_tag = d['course_tag']
        if 'origin_price' in d:
            o.origin_price = d['origin_price']
        if 'out_course_id' in d:
            o.out_course_id = d['out_course_id']
        if 'out_shop_id' in d:
            o.out_shop_id = d['out_shop_id']
        if 'price' in d:
            o.price = d['price']
        if 'shop_img_url' in d:
            o.shop_img_url = d['shop_img_url']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_url' in d:
            o.shop_url = d['shop_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SubVenueQueryInfo import SubVenueQueryInfo


class AlipayCommerceSportsVenueModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceSportsVenueModifyResponse, self).__init__()
        self._address = None
        self._area_code = None
        self._bookable = None
        self._city_code = None
        self._desc = None
        self._extra_service_url = None
        self._join_type = None
        self._latitude = None
        self._longitude = None
        self._name = None
        self._opening_hours = None
        self._out_venue_id = None
        self._phone = None
        self._picture_list = None
        self._poi = None
        self._poster = None
        self._product_type_list = None
        self._province_code = None
        self._sub_venue_list = None
        self._tag_list = None
        self._traffic = None
        self._venue_id = None
        self._venue_pid = None
        self._venue_status = None
        self._venue_type = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def area_code(self):
        return self._area_code

    @area_code.setter
    def area_code(self, value):
        self._area_code = value
    @property
    def bookable(self):
        return self._bookable

    @bookable.setter
    def bookable(self, value):
        self._bookable = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def extra_service_url(self):
        return self._extra_service_url

    @extra_service_url.setter
    def extra_service_url(self, value):
        self._extra_service_url = value
    @property
    def join_type(self):
        return self._join_type

    @join_type.setter
    def join_type(self, value):
        self._join_type = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def opening_hours(self):
        return self._opening_hours

    @opening_hours.setter
    def opening_hours(self, value):
        self._opening_hours = value
    @property
    def out_venue_id(self):
        return self._out_venue_id

    @out_venue_id.setter
    def out_venue_id(self, value):
        self._out_venue_id = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        if isinstance(value, list):
            self._phone = list()
            for i in value:
                self._phone.append(i)
    @property
    def picture_list(self):
        return self._picture_list

    @picture_list.setter
    def picture_list(self, value):
        if isinstance(value, list):
            self._picture_list = list()
            for i in value:
                self._picture_list.append(i)
    @property
    def poi(self):
        return self._poi

    @poi.setter
    def poi(self, value):
        self._poi = value
    @property
    def poster(self):
        return self._poster

    @poster.setter
    def poster(self, value):
        self._poster = value
    @property
    def product_type_list(self):
        return self._product_type_list

    @product_type_list.setter
    def product_type_list(self, value):
        if isinstance(value, list):
            self._product_type_list = list()
            for i in value:
                self._product_type_list.append(i)
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def sub_venue_list(self):
        return self._sub_venue_list

    @sub_venue_list.setter
    def sub_venue_list(self, value):
        if isinstance(value, list):
            self._sub_venue_list = list()
            for i in value:
                if isinstance(i, SubVenueQueryInfo):
                    self._sub_venue_list.append(i)
                else:
                    self._sub_venue_list.append(SubVenueQueryInfo.from_alipay_dict(i))
    @property
    def tag_list(self):
        return self._tag_list

    @tag_list.setter
    def tag_list(self, value):
        if isinstance(value, list):
            self._tag_list = list()
            for i in value:
                self._tag_list.append(i)
    @property
    def traffic(self):
        return self._traffic

    @traffic.setter
    def traffic(self, value):
        self._traffic = value
    @property
    def venue_id(self):
        return self._venue_id

    @venue_id.setter
    def venue_id(self, value):
        self._venue_id = value
    @property
    def venue_pid(self):
        return self._venue_pid

    @venue_pid.setter
    def venue_pid(self, value):
        self._venue_pid = value
    @property
    def venue_status(self):
        return self._venue_status

    @venue_status.setter
    def venue_status(self, value):
        self._venue_status = value
    @property
    def venue_type(self):
        return self._venue_type

    @venue_type.setter
    def venue_type(self, value):
        if isinstance(value, list):
            self._venue_type = list()
            for i in value:
                self._venue_type.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceSportsVenueModifyResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'area_code' in response:
            self.area_code = response['area_code']
        if 'bookable' in response:
            self.bookable = response['bookable']
        if 'city_code' in response:
            self.city_code = response['city_code']
        if 'desc' in response:
            self.desc = response['desc']
        if 'extra_service_url' in response:
            self.extra_service_url = response['extra_service_url']
        if 'join_type' in response:
            self.join_type = response['join_type']
        if 'latitude' in response:
            self.latitude = response['latitude']
        if 'longitude' in response:
            self.longitude = response['longitude']
        if 'name' in response:
            self.name = response['name']
        if 'opening_hours' in response:
            self.opening_hours = response['opening_hours']
        if 'out_venue_id' in response:
            self.out_venue_id = response['out_venue_id']
        if 'phone' in response:
            self.phone = response['phone']
        if 'picture_list' in response:
            self.picture_list = response['picture_list']
        if 'poi' in response:
            self.poi = response['poi']
        if 'poster' in response:
            self.poster = response['poster']
        if 'product_type_list' in response:
            self.product_type_list = response['product_type_list']
        if 'province_code' in response:
            self.province_code = response['province_code']
        if 'sub_venue_list' in response:
            self.sub_venue_list = response['sub_venue_list']
        if 'tag_list' in response:
            self.tag_list = response['tag_list']
        if 'traffic' in response:
            self.traffic = response['traffic']
        if 'venue_id' in response:
            self.venue_id = response['venue_id']
        if 'venue_pid' in response:
            self.venue_pid = response['venue_pid']
        if 'venue_status' in response:
            self.venue_status = response['venue_status']
        if 'venue_type' in response:
            self.venue_type = response['venue_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppServicePromotemplateQueryModel(object):

    def __init__(self):
        self._promo_booth_id = None
        self._promo_booth_version = None

    @property
    def promo_booth_id(self):
        return self._promo_booth_id

    @promo_booth_id.setter
    def promo_booth_id(self, value):
        self._promo_booth_id = value
    @property
    def promo_booth_version(self):
        return self._promo_booth_version

    @promo_booth_version.setter
    def promo_booth_version(self, value):
        self._promo_booth_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.promo_booth_id:
            if hasattr(self.promo_booth_id, 'to_alipay_dict'):
                params['promo_booth_id'] = self.promo_booth_id.to_alipay_dict()
            else:
                params['promo_booth_id'] = self.promo_booth_id
        if self.promo_booth_version:
            if hasattr(self.promo_booth_version, 'to_alipay_dict'):
                params['promo_booth_version'] = self.promo_booth_version.to_alipay_dict()
            else:
                params['promo_booth_version'] = self.promo_booth_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppServicePromotemplateQueryModel()
        if 'promo_booth_id' in d:
            o.promo_booth_id = d['promo_booth_id']
        if 'promo_booth_version' in d:
            o.promo_booth_version = d['promo_booth_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceTransportVehicleownerSettlementRefundResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportVehicleownerSettlementRefundResponse, self).__init__()
        self._buyer_id = None
        self._gmt_refund_pay = None
        self._open_id = None
        self._out_request_no = None
        self._out_trade_no = None
        self._refund_amount = None
        self._refund_status = None
        self._trade_no = None

    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def gmt_refund_pay(self):
        return self._gmt_refund_pay

    @gmt_refund_pay.setter
    def gmt_refund_pay(self, value):
        self._gmt_refund_pay = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_status(self):
        return self._refund_status

    @refund_status.setter
    def refund_status(self, value):
        self._refund_status = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportVehicleownerSettlementRefundResponse, self).parse_response_content(response_content)
        if 'buyer_id' in response:
            self.buyer_id = response['buyer_id']
        if 'gmt_refund_pay' in response:
            self.gmt_refund_pay = response['gmt_refund_pay']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'refund_amount' in response:
            self.refund_amount = response['refund_amount']
        if 'refund_status' in response:
            self.refund_status = response['refund_status']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CardAssetInfo(object):

    def __init__(self):
        self._card_no = None
        self._card_pwd = None

    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def card_pwd(self):
        return self._card_pwd

    @card_pwd.setter
    def card_pwd(self, value):
        self._card_pwd = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.card_pwd:
            if hasattr(self.card_pwd, 'to_alipay_dict'):
                params['card_pwd'] = self.card_pwd.to_alipay_dict()
            else:
                params['card_pwd'] = self.card_pwd
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CardAssetInfo()
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'card_pwd' in d:
            o.card_pwd = d['card_pwd']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppEbppBillkeyDeductQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppEbppBillkeyDeductQueryResponse, self).__init__()
        self._bill_key = None
        self._biz_type = None
        self._charge_inst = None
        self._open_id = None
        self._sub_biz_type = None
        self._user_id = None

    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppEbppBillkeyDeductQueryResponse, self).parse_response_content(response_content)
        if 'bill_key' in response:
            self.bill_key = response['bill_key']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'charge_inst' in response:
            self.charge_inst = response['charge_inst']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'sub_biz_type' in response:
            self.sub_biz_type = response['sub_biz_type']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InvoiceItemOpenModel import InvoiceItemOpenModel
from alipay.aop.api.domain.InvoiceTitleOpenModel import InvoiceTitleOpenModel


class InvoiceOutputInfo(object):

    def __init__(self):
        self._check_code = None
        self._checker = None
        self._clerk = None
        self._ex_tax_amount = None
        self._invoice_code = None
        self._invoice_content = None
        self._invoice_date = None
        self._invoice_img_url = None
        self._invoice_kind = None
        self._invoice_memo = None
        self._invoice_no = None
        self._invoice_title = None
        self._invoice_type = None
        self._ori_blue_inv_code = None
        self._ori_blue_inv_no = None
        self._payee = None
        self._payee_address_tel = None
        self._payee_bank_name_account = None
        self._payee_name = None
        self._payee_register_no = None
        self._sum_amount = None
        self._tax_amount = None

    @property
    def check_code(self):
        return self._check_code

    @check_code.setter
    def check_code(self, value):
        self._check_code = value
    @property
    def checker(self):
        return self._checker

    @checker.setter
    def checker(self, value):
        self._checker = value
    @property
    def clerk(self):
        return self._clerk

    @clerk.setter
    def clerk(self, value):
        self._clerk = value
    @property
    def ex_tax_amount(self):
        return self._ex_tax_amount

    @ex_tax_amount.setter
    def ex_tax_amount(self, value):
        self._ex_tax_amount = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_content(self):
        return self._invoice_content

    @invoice_content.setter
    def invoice_content(self, value):
        if isinstance(value, list):
            self._invoice_content = list()
            for i in value:
                if isinstance(i, InvoiceItemOpenModel):
                    self._invoice_content.append(i)
                else:
                    self._invoice_content.append(InvoiceItemOpenModel.from_alipay_dict(i))
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_img_url(self):
        return self._invoice_img_url

    @invoice_img_url.setter
    def invoice_img_url(self, value):
        self._invoice_img_url = value
    @property
    def invoice_kind(self):
        return self._invoice_kind

    @invoice_kind.setter
    def invoice_kind(self, value):
        self._invoice_kind = value
    @property
    def invoice_memo(self):
        return self._invoice_memo

    @invoice_memo.setter
    def invoice_memo(self, value):
        self._invoice_memo = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def invoice_title(self):
        return self._invoice_title

    @invoice_title.setter
    def invoice_title(self, value):
        if isinstance(value, InvoiceTitleOpenModel):
            self._invoice_title = value
        else:
            self._invoice_title = InvoiceTitleOpenModel.from_alipay_dict(value)
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def ori_blue_inv_code(self):
        return self._ori_blue_inv_code

    @ori_blue_inv_code.setter
    def ori_blue_inv_code(self, value):
        self._ori_blue_inv_code = value
    @property
    def ori_blue_inv_no(self):
        return self._ori_blue_inv_no

    @ori_blue_inv_no.setter
    def ori_blue_inv_no(self, value):
        self._ori_blue_inv_no = value
    @property
    def payee(self):
        return self._payee

    @payee.setter
    def payee(self, value):
        self._payee = value
    @property
    def payee_address_tel(self):
        return self._payee_address_tel

    @payee_address_tel.setter
    def payee_address_tel(self, value):
        self._payee_address_tel = value
    @property
    def payee_bank_name_account(self):
        return self._payee_bank_name_account

    @payee_bank_name_account.setter
    def payee_bank_name_account(self, value):
        self._payee_bank_name_account = value
    @property
    def payee_name(self):
        return self._payee_name

    @payee_name.setter
    def payee_name(self, value):
        self._payee_name = value
    @property
    def payee_register_no(self):
        return self._payee_register_no

    @payee_register_no.setter
    def payee_register_no(self, value):
        self._payee_register_no = value
    @property
    def sum_amount(self):
        return self._sum_amount

    @sum_amount.setter
    def sum_amount(self, value):
        self._sum_amount = value
    @property
    def tax_amount(self):
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, value):
        self._tax_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.check_code:
            if hasattr(self.check_code, 'to_alipay_dict'):
                params['check_code'] = self.check_code.to_alipay_dict()
            else:
                params['check_code'] = self.check_code
        if self.checker:
            if hasattr(self.checker, 'to_alipay_dict'):
                params['checker'] = self.checker.to_alipay_dict()
            else:
                params['checker'] = self.checker
        if self.clerk:
            if hasattr(self.clerk, 'to_alipay_dict'):
                params['clerk'] = self.clerk.to_alipay_dict()
            else:
                params['clerk'] = self.clerk
        if self.ex_tax_amount:
            if hasattr(self.ex_tax_amount, 'to_alipay_dict'):
                params['ex_tax_amount'] = self.ex_tax_amount.to_alipay_dict()
            else:
                params['ex_tax_amount'] = self.ex_tax_amount
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_content:
            if isinstance(self.invoice_content, list):
                for i in range(0, len(self.invoice_content)):
                    element = self.invoice_content[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.invoice_content[i] = element.to_alipay_dict()
            if hasattr(self.invoice_content, 'to_alipay_dict'):
                params['invoice_content'] = self.invoice_content.to_alipay_dict()
            else:
                params['invoice_content'] = self.invoice_content
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_img_url:
            if hasattr(self.invoice_img_url, 'to_alipay_dict'):
                params['invoice_img_url'] = self.invoice_img_url.to_alipay_dict()
            else:
                params['invoice_img_url'] = self.invoice_img_url
        if self.invoice_kind:
            if hasattr(self.invoice_kind, 'to_alipay_dict'):
                params['invoice_kind'] = self.invoice_kind.to_alipay_dict()
            else:
                params['invoice_kind'] = self.invoice_kind
        if self.invoice_memo:
            if hasattr(self.invoice_memo, 'to_alipay_dict'):
                params['invoice_memo'] = self.invoice_memo.to_alipay_dict()
            else:
                params['invoice_memo'] = self.invoice_memo
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.invoice_title:
            if hasattr(self.invoice_title, 'to_alipay_dict'):
                params['invoice_title'] = self.invoice_title.to_alipay_dict()
            else:
                params['invoice_title'] = self.invoice_title
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.ori_blue_inv_code:
            if hasattr(self.ori_blue_inv_code, 'to_alipay_dict'):
                params['ori_blue_inv_code'] = self.ori_blue_inv_code.to_alipay_dict()
            else:
                params['ori_blue_inv_code'] = self.ori_blue_inv_code
        if self.ori_blue_inv_no:
            if hasattr(self.ori_blue_inv_no, 'to_alipay_dict'):
                params['ori_blue_inv_no'] = self.ori_blue_inv_no.to_alipay_dict()
            else:
                params['ori_blue_inv_no'] = self.ori_blue_inv_no
        if self.payee:
            if hasattr(self.payee, 'to_alipay_dict'):
                params['payee'] = self.payee.to_alipay_dict()
            else:
                params['payee'] = self.payee
        if self.payee_address_tel:
            if hasattr(self.payee_address_tel, 'to_alipay_dict'):
                params['payee_address_tel'] = self.payee_address_tel.to_alipay_dict()
            else:
                params['payee_address_tel'] = self.payee_address_tel
        if self.payee_bank_name_account:
            if hasattr(self.payee_bank_name_account, 'to_alipay_dict'):
                params['payee_bank_name_account'] = self.payee_bank_name_account.to_alipay_dict()
            else:
                params['payee_bank_name_account'] = self.payee_bank_name_account
        if self.payee_name:
            if hasattr(self.payee_name, 'to_alipay_dict'):
                params['payee_name'] = self.payee_name.to_alipay_dict()
            else:
                params['payee_name'] = self.payee_name
        if self.payee_register_no:
            if hasattr(self.payee_register_no, 'to_alipay_dict'):
                params['payee_register_no'] = self.payee_register_no.to_alipay_dict()
            else:
                params['payee_register_no'] = self.payee_register_no
        if self.sum_amount:
            if hasattr(self.sum_amount, 'to_alipay_dict'):
                params['sum_amount'] = self.sum_amount.to_alipay_dict()
            else:
                params['sum_amount'] = self.sum_amount
        if self.tax_amount:
            if hasattr(self.tax_amount, 'to_alipay_dict'):
                params['tax_amount'] = self.tax_amount.to_alipay_dict()
            else:
                params['tax_amount'] = self.tax_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceOutputInfo()
        if 'check_code' in d:
            o.check_code = d['check_code']
        if 'checker' in d:
            o.checker = d['checker']
        if 'clerk' in d:
            o.clerk = d['clerk']
        if 'ex_tax_amount' in d:
            o.ex_tax_amount = d['ex_tax_amount']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_content' in d:
            o.invoice_content = d['invoice_content']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_img_url' in d:
            o.invoice_img_url = d['invoice_img_url']
        if 'invoice_kind' in d:
            o.invoice_kind = d['invoice_kind']
        if 'invoice_memo' in d:
            o.invoice_memo = d['invoice_memo']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'invoice_title' in d:
            o.invoice_title = d['invoice_title']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'ori_blue_inv_code' in d:
            o.ori_blue_inv_code = d['ori_blue_inv_code']
        if 'ori_blue_inv_no' in d:
            o.ori_blue_inv_no = d['ori_blue_inv_no']
        if 'payee' in d:
            o.payee = d['payee']
        if 'payee_address_tel' in d:
            o.payee_address_tel = d['payee_address_tel']
        if 'payee_bank_name_account' in d:
            o.payee_bank_name_account = d['payee_bank_name_account']
        if 'payee_name' in d:
            o.payee_name = d['payee_name']
        if 'payee_register_no' in d:
            o.payee_register_no = d['payee_register_no']
        if 'sum_amount' in d:
            o.sum_amount = d['sum_amount']
        if 'tax_amount' in d:
            o.tax_amount = d['tax_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityRiskVerifyidentityCommonQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityRiskVerifyidentityCommonQueryResponse, self).__init__()
        self._data = None
        self._message = None
        self._success = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityRiskVerifyidentityCommonQueryResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']
        if 'message' in response:
            self.message = response['message']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CropsYieldForecastInfo(object):

    def __init__(self):
        self._actual_date = None
        self._actual_year = None
        self._addition_info = None
        self._crop_code = None
        self._per_unit_yield = None
        self._total_yield = None

    @property
    def actual_date(self):
        return self._actual_date

    @actual_date.setter
    def actual_date(self, value):
        self._actual_date = value
    @property
    def actual_year(self):
        return self._actual_year

    @actual_year.setter
    def actual_year(self, value):
        self._actual_year = value
    @property
    def addition_info(self):
        return self._addition_info

    @addition_info.setter
    def addition_info(self, value):
        self._addition_info = value
    @property
    def crop_code(self):
        return self._crop_code

    @crop_code.setter
    def crop_code(self, value):
        self._crop_code = value
    @property
    def per_unit_yield(self):
        return self._per_unit_yield

    @per_unit_yield.setter
    def per_unit_yield(self, value):
        self._per_unit_yield = value
    @property
    def total_yield(self):
        return self._total_yield

    @total_yield.setter
    def total_yield(self, value):
        self._total_yield = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_date:
            if hasattr(self.actual_date, 'to_alipay_dict'):
                params['actual_date'] = self.actual_date.to_alipay_dict()
            else:
                params['actual_date'] = self.actual_date
        if self.actual_year:
            if hasattr(self.actual_year, 'to_alipay_dict'):
                params['actual_year'] = self.actual_year.to_alipay_dict()
            else:
                params['actual_year'] = self.actual_year
        if self.addition_info:
            if hasattr(self.addition_info, 'to_alipay_dict'):
                params['addition_info'] = self.addition_info.to_alipay_dict()
            else:
                params['addition_info'] = self.addition_info
        if self.crop_code:
            if hasattr(self.crop_code, 'to_alipay_dict'):
                params['crop_code'] = self.crop_code.to_alipay_dict()
            else:
                params['crop_code'] = self.crop_code
        if self.per_unit_yield:
            if hasattr(self.per_unit_yield, 'to_alipay_dict'):
                params['per_unit_yield'] = self.per_unit_yield.to_alipay_dict()
            else:
                params['per_unit_yield'] = self.per_unit_yield
        if self.total_yield:
            if hasattr(self.total_yield, 'to_alipay_dict'):
                params['total_yield'] = self.total_yield.to_alipay_dict()
            else:
                params['total_yield'] = self.total_yield
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CropsYieldForecastInfo()
        if 'actual_date' in d:
            o.actual_date = d['actual_date']
        if 'actual_year' in d:
            o.actual_year = d['actual_year']
        if 'addition_info' in d:
            o.addition_info = d['addition_info']
        if 'crop_code' in d:
            o.crop_code = d['crop_code']
        if 'per_unit_yield' in d:
            o.per_unit_yield = d['per_unit_yield']
        if 'total_yield' in d:
            o.total_yield = d['total_yield']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInstserviceDeductSignModel(object):

    def __init__(self):
        self._agent_channel = None
        self._agent_code = None
        self._bill_key = None
        self._biz_type = None
        self._ededuct_product_code = None
        self._extend_field = None
        self._inst_id = None
        self._open_id = None
        self._pay_mode = None
        self._sub_biz_type = None
        self._user_id = None
        self._verify_id = None

    @property
    def agent_channel(self):
        return self._agent_channel

    @agent_channel.setter
    def agent_channel(self, value):
        self._agent_channel = value
    @property
    def agent_code(self):
        return self._agent_code

    @agent_code.setter
    def agent_code(self, value):
        self._agent_code = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def ededuct_product_code(self):
        return self._ededuct_product_code

    @ededuct_product_code.setter
    def ededuct_product_code(self, value):
        self._ededuct_product_code = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def pay_mode(self):
        return self._pay_mode

    @pay_mode.setter
    def pay_mode(self, value):
        self._pay_mode = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def verify_id(self):
        return self._verify_id

    @verify_id.setter
    def verify_id(self, value):
        self._verify_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_channel:
            if hasattr(self.agent_channel, 'to_alipay_dict'):
                params['agent_channel'] = self.agent_channel.to_alipay_dict()
            else:
                params['agent_channel'] = self.agent_channel
        if self.agent_code:
            if hasattr(self.agent_code, 'to_alipay_dict'):
                params['agent_code'] = self.agent_code.to_alipay_dict()
            else:
                params['agent_code'] = self.agent_code
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = self.bill_key.to_alipay_dict()
            else:
                params['bill_key'] = self.bill_key
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.ededuct_product_code:
            if hasattr(self.ededuct_product_code, 'to_alipay_dict'):
                params['ededuct_product_code'] = self.ededuct_product_code.to_alipay_dict()
            else:
                params['ededuct_product_code'] = self.ededuct_product_code
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.pay_mode:
            if hasattr(self.pay_mode, 'to_alipay_dict'):
                params['pay_mode'] = self.pay_mode.to_alipay_dict()
            else:
                params['pay_mode'] = self.pay_mode
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.verify_id:
            if hasattr(self.verify_id, 'to_alipay_dict'):
                params['verify_id'] = self.verify_id.to_alipay_dict()
            else:
                params['verify_id'] = self.verify_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInstserviceDeductSignModel()
        if 'agent_channel' in d:
            o.agent_channel = d['agent_channel']
        if 'agent_code' in d:
            o.agent_code = d['agent_code']
        if 'bill_key' in d:
            o.bill_key = d['bill_key']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'ededuct_product_code' in d:
            o.ededuct_product_code = d['ededuct_product_code']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'pay_mode' in d:
            o.pay_mode = d['pay_mode']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'verify_id' in d:
            o.verify_id = d['verify_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenOperationBizfeeAftechRefundResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenOperationBizfeeAftechRefundResponse, self).__init__()
        self._result_code = None
        self._result_message = None

    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_message(self):
        return self._result_message

    @result_message.setter
    def result_message(self, value):
        self._result_message = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenOperationBizfeeAftechRefundResponse, self).parse_response_content(response_content)
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_message' in response:
            self.result_message = response['result_message']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TuitionISVAmountInfoDTO import TuitionISVAmountInfoDTO
from alipay.aop.api.domain.TuitionISVResult import TuitionISVResult


class AlipayOverseasOpenAmountPreconsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasOpenAmountPreconsultResponse, self).__init__()
        self._amount_info = None
        self._reference_id = None
        self._result = None

    @property
    def amount_info(self):
        return self._amount_info

    @amount_info.setter
    def amount_info(self, value):
        if isinstance(value, TuitionISVAmountInfoDTO):
            self._amount_info = value
        else:
            self._amount_info = TuitionISVAmountInfoDTO.from_alipay_dict(value)
    @property
    def reference_id(self):
        return self._reference_id

    @reference_id.setter
    def reference_id(self, value):
        self._reference_id = value
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        if isinstance(value, TuitionISVResult):
            self._result = value
        else:
            self._result = TuitionISVResult.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasOpenAmountPreconsultResponse, self).parse_response_content(response_content)
        if 'amount_info' in response:
            self.amount_info = response['amount_info']
        if 'reference_id' in response:
            self.reference_id = response['reference_id']
        if 'result' in response:
            self.result = response['result']
